<?php
namespace app\admin\content\addons\service;


use think\facade\Db;
use function resError;
use function resSuccess;
use const DS;
use const ROOT_PATH;

class AddonsService
{
    public static function getAddonsList($paramData): array
    {
        $keywords = $paramData["keywords"] ?? "";
        $addonsAllList = [];
        $dirNameAndPathArray = getLocalContentAddonsArray();
        if (count($dirNameAndPathArray) > 0) {
            foreach ($dirNameAndPathArray as $dirNameAndPath) {
                $dirNameAndPath["info"]["is_installed"] = 0;
                $dirNameAndPath["info"]["is_dirty"] = 0;
                $addonsAllList[$dirNameAndPath["name"]] = $dirNameAndPath["info"];
            }
        }
        $addonsList = db("base_addons")->select()->all();
        if (count($addonsList) > 0) {
            foreach ($addonsList as $addon) {
                $addonName = $addon["name"];
                if (isset($addonsAllList[$addonName])) {
                    $addonsAllList[$addonName]["isUpdate"] = 0;
                    $addonsAllList[$addonName]["is_installed"] = 1;
                    $addonsAllList[$addonName]["id"] = $addon["id"];
                    $addonsAllList[$addonName]["is_disable"] = $addon["is_disable"];
                    if ($addonsAllList[$addonName]["version"] != $addon["version"]) {
                        $addonsAllList[$addon["name"]]["isUpdate"] = 1;
                    }
                } else {
                    $addon["manage_entry"] = "";
                    $addon["is_dirty"] = 1;
                    $addonsAllList[$addon["name"]] = $addon;
                }
            }
        }
        $itemList = [];
        if (count($addonsAllList) > 0) {
            if ($keywords) {
                foreach ($addonsAllList as $addons) {
                    if (strpos($addons["title"],$keywords) !== false || strpos($addons["name"],$keywords) !== false) {
                        $itemList[] = $addons;
                    }
                }
            } else {
                foreach ($addonsAllList as $addons) {
                    $itemList[] = $addons;
                }
            }
        }
        return $itemList;
    }

    public static function countAddons($paramData)
    {

        $addonsAllList = [];
        $dirNameAndPathArray = getLocalContentAddonsArray();
        if (count($dirNameAndPathArray) > 0) {
            foreach ($dirNameAndPathArray as $dirNameAndPath) {
                $dirNameAndPath["info"]["is_installed"] = 0;
                $dirNameAndPath["info"]["is_dirty"] = 0;
                $addonsAllList[$dirNameAndPath["name"]] = $dirNameAndPath["info"];
            }
        }
        $addonsList = db("base_addons")->select()->all();
        if (count($addonsList) > 0) {
            foreach ($addonsList as $addon) {
                $addon["is_installed"] = 1;
                if (!isset($addonsAllList[$addon["name"]])) {
                    $addon["is_dirty"] = 1;
                }
                $addonsAllList[$addon["name"]] = $addon;
            }
        }
        $itemList = [];
        if (count($addonsAllList) > 0) {
            foreach ($addonsAllList as $addons) {
                $itemList[] = $addons;
            }
        }
        return count($itemList);
    }

    public static function getAddonsInfo($name): array
    {
        $itemInfo = db("base_addons")->where('name',$name)->find();
        if ($itemInfo) {
            return $itemInfo;
        } else {
            return [];
        }
    }
    public static function getAddonsInfoByManageEntry($manageEntry): array
    {
        $allList = self::getAddonsList([]);
        $addonsInfo = [];
        if ($allList) {
            foreach ($allList as $key => $value) {
                if ($manageEntry == $value["manage_entry"]) {
                    $addonsInfo = $value;
                }
            }
        }
        if ($addonsInfo) {
            return $addonsInfo;
        } else {
            return [];
        }
    }

    protected static function executeSql($sqlPath): array {
        if (file_exists($sqlPath)) {
            $content = file_get_contents($sqlPath);
            $content = str_replace("\r\n", "\n", $content);
            $content = str_replace("\r", "\n", $content);
            $sqlArray = explode(";\n", $content);
            $isCMS = Get("isCMS");
            if ($isCMS) {
                try {
                    foreach ($sqlArray as $sqlItemStr) {
                        $sqlItemStr = trim($sqlItemStr);
                        if (empty($sqlItemStr) || $sqlItemStr == "") continue;
                        Db::query($sqlItemStr . ";");
                    }
                } catch (\Exception $e) {
                    return resError("sql 执行失败 " . $e->getMessage());
                }
            } else {
                /*获取当前数据库名称*/
                $siteInfo =  Get("siteInfo");
                $dbName = $siteInfo["db_name"];
                /*获取数据库配置*/
                $databaseData = config("database");
                /*获取mysql链接信息*/
                $tempDatabaseConfig = $databaseData["connections"]["mysql"];
                /*将获取的mysql链接信息，修改数据库名称*/
                $tempDatabaseConfig["database"] = $dbName;
                /*新增一条链接信息*/
                $databaseData["connections"][$dbName] = $tempDatabaseConfig;
                config($databaseData,"database");
                try {
                    foreach ($sqlArray as $sqlItemStr) {
                        $sqlItemStr = trim($sqlItemStr);
                        if (empty($sqlItemStr) || $sqlItemStr == "") continue;
                        Db::connect($dbName)->query($sqlItemStr . ";");
                    }
                } catch (\Exception $e) {
                    return resError("sql 执行失败 " . $e->getMessage());
                }
            }
        }
        return resSuccess();
    }


    public static function updateAddons($paramData): array {
        $name = $paramData["name"];
        /*判断是否已经安装了*/
        $itemInfo = db("base_addons")->where('name',$name)->find();
        if (!$itemInfo) {
            return resError('该插件未安装');
        }
        /*读取插件信息*/
        $addonsPluginFile = ROOT_PATH . 'addons' . DS . $name . DS . "Addons.php";
        if (!file_exists($addonsPluginFile)) {
            return resError('插件缺少识别文件');
        }
        $tempPathInfo = pathinfo($addonsPluginFile);
        $dirName = pathinfo($tempPathInfo['dirname'], PATHINFO_FILENAME);
        $pluginClass = "\\addons\\" . $dirName . "\\" . $tempPathInfo['filename'];
        $pluginClassObj = new $pluginClass();
        if ($dirName != $pluginClassObj->info["name"]) {
            return resError('插件不匹配');
        }
        /*执行sql语句*/
        $sqlPath = ROOT_PATH . 'addons' . DS . $name . DS  . "update" . DS . 'update.sql';
        $resArray = static::executeSql($sqlPath);
        if ($resArray["err"]) {
            return $resArray;
        }
        db("base_addons")->where('name',$name)->update(["version" => $pluginClassObj->info["version"]]);
        return resSuccess();
    }

    public static function installAddons($paramData): array {
        $name = $paramData["name"];
        /*判断是否已经安装了*/
        $itemInfo = db("base_addons")->where('name',$name)->find();
        if ($itemInfo) {
            return resError('该插件已安装，无法再次安装');
        }
        /*执行sql语句*/
        $sqlPath = ROOT_PATH . 'addons' . DS . $name . DS . 'install.sql';
        $resArray = static::executeSql($sqlPath);
        if ($resArray["err"]) {
            return $resArray;
        }
        /*执行类中的install方法*/
        $class = '\\addons\\' . $name .'\\Addons';
        $addonsObj = new $class();
        if (!$addonsObj->install()) {
            return resError('插件预安装操作失败');
        }
        /*插入数据库*/
        $info = $addonsObj->info;
        $data = [
            'name' => $info['name'],
            'title' => $info['title'],
            'description' => $info['description'],
            "is_disable" => $info['is_disable'],
            'author' => $info['author'],
            'version' => $info['version'],
            "add_time" => time(),
        ];
        $id = db("base_addons")->insertGetId($data);
        return resSuccess();
    }

    public static function uninstallAddons($paramData): array {
        $name = $paramData["name"];
        /*判断是否已经安装了*/
        $itemInfo = db("base_addons")->where('name',$name)->find();
        if (!$itemInfo) {
            return resError('卸载项不存在');
        }
        /*执行sql语句*/
        $sqlPath = ROOT_PATH . 'addons' . DS . $itemInfo["name"] . DS . 'uninstall.sql';
        $resArray = static::executeSql($sqlPath);
        if ($resArray["err"]) {
            // return $resArray;
        }
        /*执行类中的install方法*/
        $class = '\\addons\\' . $name .'\\Addons';
        $addonsObj = new $class();
        if (!$addonsObj->uninstall()) {
            return resError('插件预卸载操作失败');
        }
        /*删除数据*/
        $id = db("base_addons")->where('id',$itemInfo["id"])->delete();
        return resSuccess();
    }

}
