<?php
namespace app\admin\content\article\service;

use app\common\service\CommonArticleCategoryService;
use think\facade\Db;

class ArticleCategoryService
{

    public static function addArticleCategory($paramData): array
    {
        $dataId = $paramData["data_id"] ?? 0;
        $pid = intval($paramData["pid"] ?? 0);
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $seoTitle = $paramData["seoTitle"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $template = $paramData["template"] ?? "articleCategory.html";
        $detailTemplate = $paramData["detailTemplate"] ?? "articleDetail.html";
//        $categoryUrl = $paramData["categoryUrl"] ?? "/<url_name>/";
//        $categoryPageUrl  = $paramData["categoryPageUrl"] ?? "/<url_name>/index_<page>.html";
//        $detailUrl  = $paramData["detailUrl"] ?? "/<url_name>/<id>.html";
        $isHide  = intval($paramData["isHide"] ?? 0);
        $level = intval($paramData["level"] ?? 0);
        $content = $paramData["content"] ?? "";
        if ($title == "") {
            return resError("名称不能为空");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        if (!$dataId) {
//            $dbInfo = db("article_category")->where("url_name",$urlName)->find();
//            if ($dbInfo) {
//                return resError("分类别名：". $urlName . "已存在，请重新输入");
//            }
        }
        if ($pid != 0) {
            $categoryInfo = db("article_category")->where("id",$pid)->find();
            if ($categoryInfo) {
                if ($categoryInfo["pid"] == 0) {
                    $level = 1;
                } else {
                    $level = 2;
                }
            }
        }
        /*不同分类下 别名 分类标题 允许重复*/
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "seo_title" => $seoTitle,
            "keywords" => $keywords,
            "description" => $description,
            "template" => $template,
            "detail_template" => $detailTemplate,
            'pid' => $pid,
            "is_hide" => $isHide,
            "level" => $level,
            'content' => htmlspecialchars($content),
        ];
        if ($dataId != 0) {
            $data["id"] = $dataId;
        }
        $itemId = db("article_category")->insertGetId($data);

        $url = ArticleBuildUrlService::buildArticleCategoryUrl($data);
        db("article_category")->where("id",$itemId)->update(["url" => $url,"sort" => $itemId]);
        self::updateArticleCategoryChildrenIds();
        $itemInfo = self::getArticleCategoryInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updateArticleCategory($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $pid = intval($paramData["pid"] ?? 0);
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $seoTitle = $paramData["seoTitle"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";

        $template = $paramData["template"] ?? "articleCategory.html";
        $detailTemplate = $paramData["detailTemplate"] ?? "articleDetail.html";
        $isHide = intval($paramData["isHide"] ?? 0);
        $level = intval($paramData["level"] ?? 0);
        $content = $paramData["content"] ?? "";
//        $dbInfo = db("article_category")->where("id",'<>',$id)->where("url_name",$urlName)->find();
//        if ($dbInfo) {
//            return resError("分类别名：". $urlName . "已存在，请重新输入");
//        }
        if ($pid != 0) {
            $categoryInfo = db("article_category")->where("id",$pid)->find();
            if ($categoryInfo) {
                if ($categoryInfo["pid"] == 0) {
                    $level = 1;
                } else {
                    $level = 2;
                }
            }
        }
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "seo_title" => $seoTitle,
            "keywords" => $keywords,
            "description" => $description,
            "template" => $template,
            "detail_template" => $detailTemplate,
            'pid' => $pid,
            "is_hide" => $isHide,
            "level" => $level,
            'content' => htmlspecialchars($content),
        ];
        db("article_category")->where("id", $id)->update($data);

        $itemInfo = self::getArticleCategoryInfo($id);
        if (!$itemInfo["is_diy_url"]) {
            $url = ArticleBuildUrlService::buildArticleCategoryUrl($itemInfo);
            db("article_category")->where("id",$id)->update(["url" => $url]);
        }
        self::updateArticleCategoryChildrenIds();
        return resSuccess();
    }

    public static function updateArticleCategoryUrl($id,$urlData): array
    {
        $dbInfo = db("article_category")->where("id",$id)->find();
        if (!$dbInfo) {
            return resError("分类不存在");
        }
        if ($urlData == "") {
            $url = ArticleBuildUrlService::buildArticleCategoryUrl($dbInfo);
            db("article_category")->where("id", $id)->update(["url" => $url,"is_diy_url" => 0]);
        } else {
            db("article_category")->where("id", $id)->update(["url" => $urlData,"is_diy_url" => 1]);
        }
        return resSuccess();
    }

    public static function buildArticleCategoryUrl(): array
    {
        /*更新所有站点地址*/
        $articleCategoryArray = db("article_category")->select()->all();
        if ($articleCategoryArray) {
            foreach ($articleCategoryArray as $index => $item) {
                if (!$item["is_diy_url"]) {
                    $url = ArticleBuildUrlService::buildArticleCategoryUrl($item);
                    db("article_category")->where("id", $item["id"])->update(["url" => $url]);
                }
            }
        }
        self::updateArticleCategoryChildrenIds();
        return resSuccess();
    }

    public static function updateArticleCategoryChildrenIds() {
        // Fetch all article categories
        $articleCategoryArray = db("article_category")->select()->all();

        // Create a map to organize categories by parent ID
        $categoryMap = [];
        foreach ($articleCategoryArray as $category) {
            $categoryMap[$category["pid"]][] = $category["id"];
        }

        // Create a recursive function to update children IDs
        $updateChildrenIds = function ($categoryId, $level = 0) use (&$updateChildrenIds, $categoryMap, &$articleCategoryArray) {
            // Initialize children IDs array
            $childrenIdsArray = [];
            $firstLevelChildren = [];

            // Check if the category has children
            if (isset($categoryMap[$categoryId])) {
                foreach ($categoryMap[$categoryId] as $childId) {
                    // First-level children
                    if ($level === 0) {
                        $firstLevelChildren[] = $childId;
                    }

                    // Recursively update children IDs
                    $grandchildrenIdsArray = $updateChildrenIds($childId, $level + 1);
                    $childrenIdsArray = array_merge($childrenIdsArray, [$childId], $grandchildrenIdsArray);
                }
            }

            // Update children IDs for the current category
            $allIds = implode(",", $childrenIdsArray);
            $firstLevelIds = implode(",", $firstLevelChildren);

            db("article_category")->where("id", $categoryId)->update([
                "children_all_ids" => $allIds,
                "children_ids" => $firstLevelIds,
            ]);

            return $childrenIdsArray;
        };

        // Iterate through the top-level categories
        foreach ($articleCategoryArray as $category) {
            // Update children IDs recursively
            $updateChildrenIds($category["id"]);
        }

        return [];
    }




    /*查询单个信息*/
    public static function getArticleCategoryInfo($id): array
    {
        $itemInfo = db("article_category")->where("id",$id)->find();
        if ($itemInfo) {
            $itemInfo['content'] = htmlspecialchars_decode($itemInfo['content']);
            $itemInfo["url"] = CommonArticleCategoryService::getArticleCategoryUrl($itemInfo);
            $itemInfo["children"] = CommonArticleCategoryService::getLevelChildren($itemInfo);
        } else {
            $itemInfo = [];
        }
        return $itemInfo;
    }

    public static function getArticleCategoryList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $ids = $paramData["id"] ?? "";
        $pid = intval($paramData["pid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("article_category");
        if ($pid != -1) {
            $dbSelect =$dbSelect->where("pid",$pid);
        }
        if ($ids != "") {
            $idsArray = explode(",", $ids);
            $dbSelect =$dbSelect->where("id","in",$idsArray);
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                /*级联菜单*/
                $itemList[$index]["label"] = $item["title"];
                $itemList[$index]["value"] = $item["id"];
                $itemList[$index]["isOpen"] = true;
                $itemList[$index]["urlData"] = $item["url"];
                $itemList[$index]["url"] = CommonArticleCategoryService::getArticleCategoryUrl($item);
                $itemList[$index]['content'] = htmlspecialchars_decode($item['content']);
                $itemList[$index]["children"] = CommonArticleCategoryService::getLevelChildren($item);
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countArticleCategory($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $pid = intval($paramData["pid"] ?? 0);
        $dbSelect = db("article_category")->where("pid",$pid);
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $count = $dbSelect->count("*");
        return $count;
    }


    public static function deleteArticleCategory($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                /*判断id下是否有子级*/
                if (db("article_category")->where("pid", $id)->find()) {
                    return resError("该分类中存在子级分类，请先删除子级分类");
                }
                $count = db("article")->where("cid", $id)->count("*");
                if ($count > 0) {
                    return resError("分类ID：". $id . "中存在内容，请先删除内容");
                }
                db("article_category")->where("id", $id)->delete();
            }
        }
        self::updateArticleCategoryChildrenIds();
        return resSuccess();
    }


    /*获取随机分类*/
    public static function getRandomArticleCategory(int $num): array {
        return db("article_category")->orderRaw('rand()')->limit($num)->select()->all();
    }

    public static function saveArticleCategorySort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("article_category")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }
}
