<?php
namespace app\admin\content\article\service;


use think\facade\Db;

class ArticleFieldService
{
    public static function addArticleField($paramData): array
    {
        $name = $paramData["name"] ?? "";
        $fieldName = $paramData["fieldName"] ?? "";
        $fieldType = $paramData["fieldType"] ?? "";
        $data = $paramData["data"] ?? "";
        if ($name == "") {
            return resError("名称不能为空");
        }
        if ($fieldName == "") {
            return resError("字段名不能为空");
        }
        $fieldInfo = db("article_field")->where("name",$name)->find();
        if ($fieldInfo) {
            return resError("名称已存在");
        }
        $fieldInfo = db("article_field")->where("field_name",'diy_' . $fieldName)->find();
        if ($fieldInfo) {
            return resError("字段名已存在");
        }
        if ($fieldType == 'input' || $fieldType == 'upload' || $fieldType == 'radio' || $fieldType == 'checkbox' || $fieldType == 'select') {
            $tempFieldType = ' varchar(255) NOT NULL DEFAULT ""';
        }
        if ($fieldType == 'textarea' || $fieldType == 'edit') {
            $tempFieldType = ' longtext';
        }
        if ($fieldType == 'int' || $fieldType == 'date') {
            $tempFieldType = ' int(11) DEFAULT 0';
        }
        if ($fieldType == 'decimal') {
            $tempFieldType = ' decimal(11,2) DEFAULT 0.00';
        }
        $isCMS = Get("isCMS");
        if ($isCMS) {
            try {
                $sql = 'ALTER TABLE article ADD ' . 'diy_' . $fieldName . $tempFieldType;
                Db::query($sql);
            } catch(\Exception $e) {
                return resError("添加失败，原因：" . $e->getMessage());
            }
        } else {
            $sql = 'ALTER TABLE article ADD ' . 'diy_' . $fieldName . $tempFieldType;
            $resData = self::executeSql($sql);
            if ($resData["err"]) {
                return resError($resData["err"]);
            }
        }
        $data = [
            "name" => $name,
            "field_name" => 'diy_' . $fieldName,
            "field_type" => $fieldType,
            'data' => $data,
        ];
        $itemId = db("article_field")->insertGetId($data);
        return resSuccess();
    }

    public static function updateArticleField($paramData): array
    {
        $id = $paramData["id"] ?? "0";
        $name = $paramData["name"] ?? "";
        $fieldName = $paramData["fieldName"] ?? "";
        $fieldNewName = $paramData["fieldNewName"] ?? "";
        $fieldType = $paramData["fieldType"] ?? "";
        $data = $paramData["data"] ?? "";
        if ($id == 0) {
            return resError("ID不能为空");
        }
        if ($name == "") {
            return resError("名称不能为空");
        }
        if ($fieldName == "") {
            return resError("字段名不能为空");
        }
        $fieldInfo = db("article_field")->where("id","<>",$id)->where("name",$name)->find();
        if ($fieldInfo) {
            return resError("名称已存在");
        }
        if ($fieldNewName) {
            $fieldInfo = db("article_field")->where("id","<>",$id)->where("field_name",'diy_' . $fieldNewName)->find();
            if ($fieldInfo) {
                return resError("字段名已存在");
            }
        } else {
            $fieldInfo = db("article_field")->where("id","<>",$id)->where("field_name",'diy_' . $fieldName)->find();
            if ($fieldInfo) {
                return resError("字段名已存在");
            }
        }
        if ($fieldType == 'input' || $fieldType == 'upload' || $fieldType == 'radio' || $fieldType == 'checkbox' || $fieldType == 'select') {
            $tempFieldType = ' varchar(255) NOT NULL DEFAULT ""';
        }
        if ($fieldType == 'textarea' || $fieldType == 'edit') {
            $tempFieldType = ' longtext';
        }
        if ($fieldType == 'int' || $fieldType == 'date') {
            $tempFieldType = ' int(11) DEFAULT 0';
        }
        if ($fieldType == 'decimal') {
            $tempFieldType = ' decimal(11,2) DEFAULT 0.00';
        }
        if ($fieldNewName && $fieldName != $fieldNewName) {
            $isCMS = Get("isCMS");
            if ($isCMS) {
                try {
                    $sql = 'ALTER TABLE article CHANGE ' . 'diy_' . $fieldName . ' ' . 'diy_' . $fieldNewName . $tempFieldType;
                    Db::query($sql);
                } catch(\Exception $e) {
                    return resError("修改失败，原因：" . $e->getMessage());
                }
            } else {
                $sql = 'ALTER TABLE article CHANGE ' . 'diy_' . $fieldName . ' ' . 'diy_' . $fieldNewName . $tempFieldType;
                $resData = self::executeSql($sql);
                if ($resData["err"]) {
                    return resError($resData["err"]);
                }
            }
            $data = [
                "name" => $name,
                "field_name" => 'diy_' . $fieldNewName,
                "field_type" => $fieldType,
                'data' => $data,
            ];
        } else {
            $data = [
                "name" => $name,
                "field_type" => $fieldType,
                'data' => $data,
            ];
        }
        db("article_field")->where("id",$id)->update($data);
        return resSuccess();
    }
    /*查询单个信息*/
    public static function getArticleFieldInfo($id) {
        $itemInfo = db("article_field")->where("id",$id)->find();
        if ($itemInfo) {
            $itemInfo['data'] = explode(',', $itemInfo['data']);
            return $itemInfo;
        }
        return [];
    }
    public static function getArticleFieldList($paramData): array
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $itemList = [];
        $itemList = db("article_field")->page($page,$limit)->order($orderBy,$order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countArticleField($paramData): int
    {
        $count = db("article_field")->count("*");
        return $count;
    }

    /*删除*/
    public static function deleteArticleField($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("article_field")->where("id",$id)->find();
                $isCMS = Get("isCMS");
                if ($isCMS) {
                    try {
                        Db::query($sql);
                    } catch(\Exception $e) {
                        return resError("删除失败，原因：" . $e->getMessage());
                    }
                } else {
                    $sql = 'ALTER TABLE article drop ' . $itemInfo['field_name'];
                    $resData = self::executeSql($sql);
                    if ($resData["err"]) {
                        return resError($resData["err"]);
                    }
                }
                db("article_field")->where("id",$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function saveArticleFieldSort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("article_field")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }

    protected static function executeSql($sql): array {
        /*获取当前数据库名称*/
        $siteInfo =  Get("siteInfo");
        $dbName = $siteInfo["db_name"];
        /*获取数据库配置*/
        $databaseData = config("database");
        /*获取mysql链接信息*/
        $tempDatabaseConfig = $databaseData["connections"]["mysql"];
        /*将获取的mysql链接信息，修改数据库名称*/
        $tempDatabaseConfig["database"] = $dbName;
        /*新增一条链接信息*/
        $databaseData["connections"][$dbName] = $tempDatabaseConfig;
        config($databaseData,"database");
        try {
            Db::connect($dbName)->query($sql);
        } catch (\Exception $e) {
            return resError("sql 执行失败 " . $e->getMessage());
        }
        return resSuccess();
    }
}
