<?php
namespace app\admin\content\article\service;

use addons\articleImgLocal\service\ArticleImgLocalService;

use app\admin\content\addons\service\AddonsService;
use app\admin\content\push\service\PushService;
use app\admin\content\search\service\SearchWordsRelService;
use app\admin\content\special\service\SpecialRelService;
use app\admin\content\statistics\service\StatisticsService;
use app\admin\content\tag\service\TagRelService;
use app\common\service\CommonArticleCategoryService;
use app\common\service\CommonArticleService;
use think\facade\Cache;
use think\facade\Db;

class ArticleService
{
    public static function addArticle($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $publishTime = $paramData["publish_time"] ?? 0 ?: time();
        $cid = intval($paramData["cid"] ?? 0);
        $isRecommend = intval($paramData["isRecommend"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $tags = $paramData["tags"] ?? "";
        $views = intval($paramData["views"] ?? 0);
        $content = $paramData["content"] ?? "";
        $description = $paramData["description"] ?? "";
        $imgUrl = $paramData["imgUrl"] ?? "";
        $isElite = intval($paramData["isElite"] ?? 0);
        $isTop = intval($paramData["isTop"] ?? 0);

        $urlName = $paramData["urlName"] ?? "";

        $fieldList = $paramData["fieldList"] ?? "";
        $fieldList = json_decode($fieldList,true);
        if ($description == "") {
            $description = mb_substr(str_replace('"','',deleteHtml($content)),0,88,'utf-8');
        }
        if ($title == "") {
            return resError("标题不能为空");
        }
        $imgRes = getImgData($imgUrl,$content);
//            "img_url_data" => $imgRes["img_url_data"] ?? "",
        /*标签去重*/
        if ($tags != "") {
            $tags = explode(",",$tags);
            $tagsArray = array_unique($tags);
            $tags = implode(",", $tagsArray);
        }
        if ($urlName == "") {
//            $urlName = titleToURL($title,"getPinyin");
        }
        $data = [
            "title" => htmlspecialchars($title),
            "cid" => $cid,
            "views" => $views,
            "is_recommend" => $isRecommend,
            "keywords" => $keywords,
            "description" => $description,
            "img_url" => $imgRes["img_url"] ?? "",
            "tags" => $tags,
            "publish_time" => $publishTime,
            "is_elite" => $isElite,
            "is_top" => $isTop,
            "url_name" => $urlName,
        ];
        $dataId = $paramData["data_id"] ?? 0;
        if ($dataId != 0) {
            $data["id"] = $dataId;
        }
        $itemId = db("article")->insertGetId($data);

        /*内容处理逻辑*/
        $addonsInfo = AddonsService::getAddonsInfo("articleImgLocal");
        if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
            $content = ArticleImgLocalService::download($content);
        }
        db("article_content")->insertGetId([
            "item_id" => $itemId,
            'content' => htmlspecialchars($content)
        ]);
        /*更新自定义字段信息*/
        if (is_array($fieldList) && $fieldList) {
            $resArray = [];
            for ($i = 0; $i < count($fieldList); $i++) {
                $resArray[$fieldList[$i]['field_name']] = $fieldList[$i]['value'];
            }
            if ($resArray) {
                try {
                    db("article")->where('id',$itemId)->update($resArray);
                } catch(\Exception $e) {
                    return errorData("发生错误，原因：" . $e->getMessage(),$itemId);
                }
            }
        }
        /*标签*/
        TagRelService::addTagRel(["tags" => $tags,"relType" => "a","itemId" => $itemId]);
        /*搜索*/
        SearchWordsRelService::addSearchWordsRel(["title" => $title,"itemId" => $itemId,"relType" => "a"]);

        StatisticsService::updateArticleCount([]);

        PushService::submitPush(["itemType" => "article","pushType" => "baiduDefaultPush","itemIds" => $itemId]);

        $itemInfo = self::getArticleInfo($itemId);

        $url = ArticleBuildUrlService::buildArticleUrl($itemInfo);
        db("article")->where("id", $itemId)->update([
            "url" => $url,
        ]);

        $itemInfo = self::getArticleInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updateArticle($paramData): array
    {
        $id = $paramData["id"] ?? "0";
        $title = $paramData["title"] ?? "";
        $publishTime = $paramData["publish_time"] ?? 0 ?: time();
        $cid = intval($paramData["cid"] ?? 0);
        $isRecommend = intval($paramData["isRecommend"] ?? 0);
        $tags = $paramData["tags"] ?? "";
        $views = intval($paramData["views"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $content = $paramData["content"] ?? "";
        $imgUrl = $paramData["imgUrl"] ?? "";
        $isElite = intval($paramData["isElite"] ?? 0);
        $isTop = intval($paramData["isTop"] ?? 0);
        $urlName = $paramData["urlName"] ?? "";
        $fieldList = $paramData["fieldList"] ?? "";
        $fieldList = json_decode($fieldList,true);
        $imgRes = [];
        if ($content != "") {
            $imgRes = getImgData($imgUrl,htmlspecialchars($content));
//            "img_url_data" => $imgRes["img_url_data"],
        }
        if ($id == 0) {
            return resError("ID不能为空");
        }
        if ($title == "") {
            return resError("标题不能为空");
        }
        /*标签去重*/
        if ($tags != "") {
            $tags = explode(",",$tags);
            $tagsArray = array_unique($tags);
            $tags = implode(",", $tagsArray);
        }
        $data = [
            "title" => htmlspecialchars($title),
            "cid" => $cid,
            "views" => $views,
            "is_recommend" => $isRecommend,
            "keywords" => $keywords,
            "description" => $description,
            "img_url" => $imgRes["img_url"] ?? "",
            "tags" => $tags,
            "publish_time" => $publishTime,
            "is_elite" => $isElite,
            "is_top" => $isTop,
            "url_name" => $urlName,
        ];
        db("article")->where("id",$id)->update($data);

        db("article_content")->where("item_id",$id)->update([
            'content' => htmlspecialchars(htmlpurifier($content))
        ]);

        /*更新自定义字段信息*/
        if (is_array($fieldList) && $fieldList) {
            $resArray = [];
            for ($i = 0; $i < count($fieldList); $i++) {
                $resArray[$fieldList[$i]['field_name']] = $fieldList[$i]['value'];
            }
            if ($resArray) {
                try {
                    db("article")->where('id',$id)->update($resArray);
                } catch(\Exception $e) {
                    return resError("发生错误，原因：" . $e->getMessage());
                }
            }
        }
        /*标签*/
        TagRelService::addTagRel(["tags" => $tags,"relType" => "a","itemId" => $id]);
        /*搜索*/
        SearchWordsRelService::addSearchWordsRel(["title" => $title,"itemId" => $id,"relType" => "a"]);
        return resSuccess();
    }

    public static function updateArticleIndex() {
        $siteInfo = Get("siteInfo");
        $currentArticleIndex = Cache::get('current_article_index_' . $siteInfo["id"]);
        $currentArticleCid = Cache::get('current_article_cid_' . $siteInfo["id"]);
        if (!$currentArticleCid) {
            $currentArticleCid = 0;
        }
        if (!$currentArticleIndex) {
            $currentArticleIndex = 0;
        }
        if ($currentArticleCid == 0) {
            $categoryList = db("article_category")->limit(1)->where("id",">",$currentArticleCid)->order("id","asc")->select()->all();
            if ($categoryList && $categoryInfo = $categoryList[0]) {
                db("article_ids")->where("cid",$categoryInfo["id"])->delete(true);
            }
        } else {
            /*有值 两种情况，更新一半 更新完*/
            if ($currentArticleIndex == 0) {
                //更新完
                $categoryList = db("article_category")->limit(1)->where("id",">",$currentArticleCid)->order("id","asc")->select()->all();
                if ($categoryList && $categoryInfo = $categoryList[0]) {
                    db("article_ids")->where("cid",$categoryInfo["id"])->delete(true);
                }
            } else {
                $categoryList = db("article_category")->limit(1)->where("id",$currentArticleCid)->order("id","asc")->select()->all();
            }
        }
        $idsArray = [];
        if ($categoryList) {
            $categoryInfo = $categoryList[0];
            Cache::set('current_article_cid_' . $siteInfo["id"],  $categoryInfo["id"]);
            $itemList = db("article")->where("cid",$categoryInfo["id"])->where("id",">",$currentArticleIndex)->limit(1000)->order("id","asc")->select()->all();
            if ($itemList) {
                foreach ($itemList as $index => $item) {
                    $idsArray[] = $item["id"];
                    Cache::set('current_article_index_' . $siteInfo["id"],  $item["id"]);
                }
                $ids = implode(",", $idsArray);
                db("article_ids")->insertGetId([
                    'ids' => $ids,
                    'cid' => $categoryInfo["id"],
                    'num' => count($idsArray),
                ]);
            } else {
                Cache::set('current_article_index_' . $siteInfo["id"],  "");
            }
        } else {
            Cache::set('current_article_cid_' . $siteInfo["id"],  "");
            Cache::set('current_article_index_' . $siteInfo["id"],  "");
            return resSuccess("end");
        }

        return resSuccess($idsArray);
    }

    public static function updateArticleUrl(): array
    {
        $siteInfo = Get("siteInfo");
        $currentArticleUrlValue = Cache::get('current_article_url_' . $siteInfo["id"]);
        if (!$currentArticleUrlValue) {
            $currentArticleUrlValue = 10000000;
        }
        $tempList = [];
        /*更新所有站点地址*/
        $itemList = db("article")->limit(1000)->where("id","<",$currentArticleUrlValue)->order("id","desc")->select()->all();
        if ($itemList) {
            foreach ($itemList as $index => $item) {
                $url = ArticleBuildUrlService::buildArticleUrl($item);
                $tempList[] = $item["id"];
                db("article")->where("id", $item["id"])->update(["url" => $url]);
                Cache::set('current_article_url_' . $siteInfo["id"],  $item["id"]);
            }
        } else {
            Cache::set('current_article_url_' . $siteInfo["id"],  "");
            return resSuccess("end");
        }
        return resSuccess($tempList);
    }
    /*查询单个信息*/
    public static function getArticleInfo($id,$paramItemInfo = null) {
        if (!$paramItemInfo) {
            $itemInfo = db("article")->where("id",$id)->find();
        } else {
            $itemInfo = $paramItemInfo;
        }
        if ($itemInfo) {
            /*分类被删除，文章还保留之前分类情况 取默认分类*/
            $categoryInfo = ArticleCategoryService::getArticleCategoryInfo($itemInfo["cid"]);
            if ($categoryInfo) {
                $itemInfo["categoryInfo"] = $categoryInfo;
            } else {
                $itemInfo["categoryInfo"] = CommonArticleCategoryService::configDefaultCategoryInfo();
            }
            $itemInfo = self::getArticleContentInfo($itemInfo);
            $itemInfo["url"] = CommonArticleService::getArticleUrl($itemInfo);
            if ($itemInfo["img_url"]) {
                $itemInfo["firstImg"] = $itemInfo["img_url"];
            } else {
                $itemInfo["firstImg"] = "/static/common/images/no-images.jpg";
            }
            return $itemInfo;
        }
        return [];
    }

    /*查询内容信息*/
    public static function getArticleContentInfo($itemInfo) {
        $itemContentInfo = db("article_content")->where("item_id",$itemInfo["id"])->find();
        if ($itemContentInfo) {
            $itemInfo["content"] = htmlspecialchars_decode($itemContentInfo["content"]);
        } else {
            $itemInfo["content"] = "";
        }
        return $itemInfo;
    }

    public static function getArticleList($paramData): array
    {
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "desc";
        $keywords = $paramData["keywords"] ?? "";
        $ids = $paramData["id"] ?? "";
        $specialId = intval($paramData["specialId"] ?? 0);
        $isManage = $paramData["isManage"] ?? "";

        $itemList = [];
        $dbSelect = db("article");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        if ($cid != 0) {
            $tempArray = CommonArticleCategoryService::buildArticleCategoryRelIdsById($cid);
            $dbSelect = $dbSelect->where("cid","in",$tempArray);
        }
        if ($ids != "") {
            if (strpos($ids,",") !== false) {
                $idsArray = explode(",", $ids);
                $dbSelect->where("id","in",$idsArray);
            } else {
                $dbSelect->where("id",$ids);
            }
            $order= 'field(id,'.$ids.')';
            $itemList = $dbSelect->order(Db::raw($order))->select()->all();
        } else {
            $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index]["selected"] = false;
                if ($isManage && $specialId != 0) {
                    $articleSpecialRelList = SpecialRelService::getSpecialRelList(["specialId" => $specialId,"relType" => "a",]);
                    if (count($articleSpecialRelList) > 0) {
                        foreach ($articleSpecialRelList as $k => $v) {
                            if ($item["id"] == $v["item_id"]) {
                                $itemList[$index]["selected"] = true;
                            }
                        }
                    }
                }

                /*分类被删除，文章还保留之前分类情况 取默认分类*/
                $categoryInfo = ArticleCategoryService::getArticleCategoryInfo($item["cid"]);
                if ($categoryInfo) {
                    $itemList[$index]["categoryInfo"] = $categoryInfo;
                } else {
                    $itemList[$index]["categoryInfo"] = CommonArticleCategoryService::configDefaultCategoryInfo();
                }
                $itemList[$index]["url"] = CommonArticleService::getArticleUrl($itemList[$index]);
                if ($itemList[$index]["img_url"]) {
                    $itemList[$index]["firstImg"] = $itemList[$index]["img_url"];
                } else {
                    $itemList[$index]["firstImg"] = "/static/common/images/no-images.jpg";
                }
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countArticle($paramData): int
    {
        $cid = intval($paramData["cid"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $tagId = intval($paramData["tagId"] ?? 0);
        $ids = $paramData["id"] ?? "";
        $count = 0;
        if (!$tagId) {
            $dbSelect = db("article");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title", "like", "%" . $keywords . "%");
            }
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid", $cid);
            }
            if ($ids != "") {
                if (strpos($ids,",") !== false) {
                    $idsArray = explode(",", $ids);
                    $dbSelect->where("id","in",$idsArray);
                } else {
                    $dbSelect->where("id",$ids);
                }
            }
            $count = $dbSelect->count("*");
        }
        return $count;
    }

    /*删除*/
    public static function deleteArticle($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $articleInfo = db("article")->where("id",$id)->find();
                if ($articleInfo) {
                    db("article")->where("id",$id)->delete();
                    db("article_content")->where("item_id",$id)->delete();
                    /*标签*/
                    TagRelService::deleteTagRel(["itemId" => $id,"relType" => "a"]);
                    /*搜索*/
                    SearchWordsRelService::deleteSearchRel(["itemId" => $id,"relType" => "a"]);
                }
            }
        }
        StatisticsService::updateArticleCount([]);
        return resSuccess();
    }

    public static function updateArticleRecommend($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $isRecommend = intval($paramData["isRecommend"] ?? 0);
        if ($isRecommend != 0) {
            $isRecommend = 1;
        }
        db("article")->where("id", $id)->update(["is_recommend" => $isRecommend]);
        return resSuccess();
    }

    public static function updateArticleView($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $views = intval($paramData["views"] ?? 0);
        if ($views < 0) {
            $views = 0;
        }
        db("article")->where("id", $id)->update(["views" => $views]);
        return resSuccess();
    }

    public static function transferArticle($paramData): array
    {
        $ids = $paramData["ids"] ?? "";
        $cid = intval($paramData["cid"] ?? 0);
        if ($ids == "") {
            return resError("ids参数不能为空");
        }
        if ($cid == 0) {
            return resError("分类不能为空");
        }
        $ids = explode(',',$ids);
        if (is_array($ids)) {
            foreach ($ids as $id) {
                db("article")->where('id',$id)->update(['cid' => $cid]);
            }
        }
        return resSuccess();
    }


    public static function batchAddArticleTag($paramData): array
    {
        $ids = $paramData["ids"] ?? "";
        $tags = $paramData["tags"] ?? "";
        $addType = $paramData["addType"] ?? "add";
        if ($ids == "") {
            return resError("ids参数不能为空");
        }
        if ($tags == "") {
            return resError("标签不能为空");
        }
        $ids = explode(',',$ids);
        if (is_array($ids)) {
            foreach ($ids as $id) {
                TagRelService::addTagRel(["tags" => $tags,"relType" => "a","itemId" => $id,"addType" => $addType]);
                /*更新文章显示标签*/
                $tagStrList = [];
                $tempTagRelList = db("tag_rel")->field("tag_id")->where("item_id",$id)->order("id","asc")->select()->all();
                if (count($tempTagRelList) > 0) {
                    foreach ($tempTagRelList as $key => $item) {
                        $tempTagInfo = db("tag")->field("title")->where("id",$item["tag_id"])->find();
                        if ($tempTagInfo) {
                            $tagStrList[] = $tempTagInfo["title"];
                        }
                    }
                }
                if ($tagStrList) {
                    db("article")->where("id",$id)->update(["tags" => implode(",",$tagStrList)]);
                }
            }
        }
        return resSuccess();
    }
}
