<?php
namespace app\admin\content\domain\controller;

use app\admin\content\domain\service\DomainService;
use app\common\controller\AdminBase;
use think\facade\Db;

class DomainController extends AdminBase
{
    /*添加域名*/
    public function addDomain()
    {
        $postData = input("post.itemInfo/a");
        if (!$postData) {
            return jsonError("参数错误");
        }
        $resData = DomainService::addDomain($postData);
        if ($resData["err"]) {
            return jsonError($resData["err"]);
        }
        return jsonSuccess('添加成功',$resData["data"]);
    }
    /*添加域名*/
    public function addDomains()
    {
        $domains = input('post.domains');
        $siteId = input('post.siteId');
        if (!$domains) {
            return jsonError('缺少参数');
        }
        $domains = explode('<>',$domains);

        /*检测*/
        $isCMS = Get("isCMS");
        if (is_array($domains)) {
            foreach ($domains as $item) {
                if ($item) {
                    $tempItemArray = explode('|',$item);
                    if (isset($tempItemArray[0]) && $tempItemArray[0] != "") {
                        $domain = $tempItemArray[0];
                        $domainInfo = db("base_domain")->where("domain",$domain)->find();
                        if ($domainInfo) {
                            return jsonError("域名已存在");
                        }
                        if (!$isCMS) {
                            $siteInfo = Db::name("site")->where("domain",$domain)->find();
                            if ($siteInfo) {
                                return jsonError("域名已存在");
                            }
                        }
                    }
                }
            }
        }

        if (is_array($domains)) {
            foreach ($domains as $item) {
                if ($item) {
                    $tempItemArray = explode('|',$item);
                    if (isset($tempItemArray[0]) && $tempItemArray[0] != "") {
                        $domain = trim($tempItemArray[0]);
                        $siteName = "";
                        $keywords = "";
                        $description = "";
                        if (isset($tempItemArray[1]) && $tempItemArray[1]) {
                            $siteName = $tempItemArray[1];
                        }
                        if (isset($tempItemArray[2]) && $tempItemArray[2]) {
                            $keywords = $tempItemArray[2];
                        }
                        if (isset($tempItemArray[3]) && $tempItemArray[3]) {
                            $description = $tempItemArray[3];
                        }
                        $postData = [
                            "domain" => $domain,
                        ];
                        $settingData = [
                            "siteName" => $siteName,
                            "keywords" => $keywords,
                            "description" => $description,
                            "template" => "default",
                        ];
                        $resData = DomainService::addDomain($postData);
                        if ($resData["err"]) {
                            return jsonError($resData["err"]);
                        }
                        DomainService::updateDomainData($resData["data"]["id"],$settingData);
                    }
                }
            }
            return jsonSuccess('添加成功');
        } else {
            return  jsonError('格式错误');
        }
    }

    /*更新修改*/
    public function updateDomain()
    {
        $postData = input("post.itemInfo/a");
        if (!$postData) {
            return jsonError("参数错误");
        }
        $resData = DomainService::updateDomain($postData);
        if ($resData["err"]) {
            return jsonError($resData["err"]);
        }
        return jsonSuccess('修改成功');
    }

    public function updateDomainData()
    {
        $id = input('post.id');
        $setting = input('post.setting/a');
        if (!$id) {
            return jsonError("参数错误");
        }
        $resData = DomainService::updateDomainData($id,$setting);
        if ($resData["err"]) {
            return jsonError($resData["err"]);
        }
        return jsonSuccess('修改成功');
    }

    public function getDomainInfo(): \think\Response
    {
        $id = intval(input("post.id") ?? 0);
        $resData = DomainService::getDomainInfo($id,[]);
        return jsonSuccess('成功',$resData);
    }

    public function getDomainList(): \think\Response
    {
        $page = intval(input("post.page") ?? 1);
        $postData = $this->request->post();
        $itemList = DomainService::getDomainList($postData);
        $total = DomainService::countDomain($postData);
        if (count($itemList) > 0) {
            $data["itemList"] = $itemList;
        } else {
            $data["itemList"] = [];
        }
        $data["total"] = $total;
        $data["page"] = $page;
        return jsonSuccess('',$data);
    }


    public function deleteDomain()
    {
        $ids = input("post.ids");
        if ($ids == "") {
            return jsonError("缺少ids参数");
        }
        $resData = DomainService::deleteDomain($ids);
        if ($resData["err"]) {
            return jsonError($resData["err"]);
        }
        return jsonSuccess("删除成功");
    }

    public function templateRandom()
    {
        $randomType = input('post.randomType');
        $templatePath = config("view.view_dir_name");
        $dirList = array();
        if (is_dir($templatePath)) {
            $dirHandle = opendir($templatePath);
            while (($file = readdir($dirHandle)) !== false) {
                if (substr($file, 0, 1) != '.' AND is_dir($templatePath . DS . $file)) {
                    $dirList[] = $file;
                }
            }
            closedir($dirHandle);
        }
        $itemList = [];
        if (count($dirList) > 0) {
            foreach ($dirList as $key => $item) {
                $jsonFile = $templatePath . DS . $item . DS . "template.json";
                if (is_file($jsonFile)) {
                    $content = file_get_contents($jsonFile);
                    $content = json_decode($content,true);
                    $itemList[] = ["fileName" => $item,"info" => $content];
                }
            }
        }
        if ($dirList) {
            $templateArray = array();
            foreach ($itemList as $key => $val) {
                if ($val && $val["fileName"] != 'default') {
                    $templateArray[] = $val;
                }
            }
        }
        $siteList = db('base_domain')->select()->all();
        if ($siteList) {
            foreach ($siteList as $key => $value) {
                $data = json_decode($value['data'],true);
                if (isset($data['template']) && $data['template'] == 'default') {
                    $index = array_rand($templateArray,1);
                    $data['template'] = $templateArray[$index]["fileName"];
                    db('base_domain')->where('id',$value['id'])->update(array(
                        'data' => json_encode($data)
                    ));
                }
            }
        }
        return jsonSuccess('操作成功');

    }
}