<?php
namespace app\admin\content\domain\service;


use think\facade\Db;

class DomainService
{
    public static function addDomain($paramData): array
    {
        $domain = $paramData["domain"] ?? "";
        $httpType = $paramData["httpType"] ?? "http://";
        $domain = trim($domain);
        $httpType = trim($httpType);
        if ($domain == "") {
            return resError("域名不能为空");
        }
        $domainInfo = db("base_domain")->where("domain",$domain)->find();
        if ($domainInfo) {
            return resError("域名已存在");
        }
        $isCMS = Get("isCMS");
        if (!$isCMS) {
            $siteInfo = Db::name("site")->where("domain",$domain)->find();
            if ($siteInfo) {
                return resError("域名已存在");
            }
        }
        $data = [
            'domain' => $domain,
            'http_type' => $httpType,
        ];
        $itemId = db("base_domain")->insertGetId($data);
        $siteInfo = getCurrentSiteInfo();
        if (!$isCMS) {
            Db::name("site")->insertGetId([
                'pid' => $siteInfo["id"],
                'domain' => $domain,
                "domain_rel_id" => $itemId,
                'http_type' => $httpType,
                'web_url' => $httpType . $domain,
            ]);
        }
        $itemInfo = self::getDomainInfo($itemId,[]);
        return resSuccess($itemInfo);
    }

    public static function updateDomain($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $domain = $paramData["domain"] ?? "";
        $httpType = $paramData["httpType"] ?? "http://";
        $domain = trim($domain);
        $httpType = trim($httpType);
        if ($domain == "") {
            return resError("域名不能为空");
        }
        $itemInfo = db('base_domain')->where('id',$id)->find();
        if (!$itemInfo) {
            return resError("修改项不存在");
        }
        $isCMS = Get("isCMS");
        if (!$isCMS) {
            $siteInfo = Db::name("site")->where("domain", $domain)->find();
            if ($siteInfo) {
                return resError("域名已存在");
            }
        }
        $itemInfo = db('base_domain')->where('id','<>',$id)->where('domain',$domain)->find();
        if ($itemInfo) {
            return resError("域名已存在，请重新输入");
        }
        $data = [
            'domain' => $domain,
            'http_type' => $httpType,
        ];
        db("base_domain")->where("id", $id)->update($data);
        if (!$isCMS) {
            Db::name("site")->where("domain_rel_id", $id)->insertGetId([
                'domain' => $domain,
                'http_type' => $httpType,
                'web_url' => $httpType . $domain,
            ]);
        }
        return resSuccess();
    }

    public static function updateDomainData($id,$setting): array
    {
        $id = intval($id);
        $itemInfo = db('base_domain')->where('id',$id)->find();
        if (!$itemInfo) {
            return resError("修改项不存在");
        }
        db('base_domain')->where('id',$id)->update(array(
            'data' => json_encode($setting),
        ));
        return resSuccess();
    }

    /*查询单个信息*/
    public static function getDomainInfo($id, $paramItemInfo) {
        if (!$paramItemInfo) {
            $itemInfo = db("base_domain")->where("id",$id)->find();
        } else {
            $itemInfo = $paramItemInfo;
        }
        if (!$itemInfo) {
            return [];
        }
        $itemInfo['data'] = json_decode($itemInfo['data'],true);
        return $itemInfo;
    }

    public static function getDomainList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = ($paramData["orderBy"] ?? "id") ?: "id";
        $order = ($paramData["order"] ?? "asc") ?: "asc";
        $keywords = $paramData["keywords"] ?? "";

        $itemList = [];
        $dbSelect = db("base_domain");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("domain","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        if ($itemList) {
            foreach ($itemList as $key => $value) {
                $itemList[$key]['data'] = json_decode($value['data'],true);
            }
        }
        return $itemList;
    }


    /*查询总数*/
    public static function countDomain($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $count = 0;
        $dbSelect = db("base_domain");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("domain", "like", "%" . $keywords . "%");
        }
        $count = $dbSelect->count("*");
        return $count;
    }

    /*删除*/
    public static function deleteDomain($ids): array
    {
        $isCMS = Get("isCMS");
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $tagInfo = db("base_domain")->where("id", $id)->find();
                if ($tagInfo) {
                    db("base_domain")->where("id", $id)->delete();
                }
                if (!$isCMS) {
                    $siteInfo = Db::name("site")->where("domain_rel_id", $id)->find();
                    if ($siteInfo) {
                        Db::name("site")->where("domain_rel_id", $id)->delete();
                    }
                }
            }
        }
        return resSuccess();
    }

}