<?php
namespace app\admin\content\page\service;


class PageService
{
    public static function addPage($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $template = $paramData["template"] ?? "";
        $content = $paramData["content"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        if ($title == "") {
            return resError('请输入名称');
        }
        if ($urlName == "") {
            return resError('请输入别名');
        }
        $itemInfo = db("page")->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemInfo = db("page")->where('url_name',$urlName)->find();
        if ($itemInfo) {
            return resError('别名已存在，请重新输入');
        }
        $itemId = db("page")->insertGetId(array(
            'title' => $title,
            'url_name' => $urlName,
            'template' => $template,
            'keywords' => $keywords,
            'description' => $description,
            'content' => htmlspecialchars($content),
        ));
        $itemInfo = self::getPageInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updatePage($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $template = $paramData["template"] ?? "";
        $content = $paramData["content"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        if (!$id) {
            return resError('缺少参数');
        }
        if (!$title) {
            return resError('请输入名称');
        }
        if (!$urlName) {
            return resError('请输入别名');
        }
        $itemInfo = db("page")->where('id',$id)->find();
        if (!$itemInfo) {
            return resError('修改项不存在');
        }
        $itemInfo = db("page")->where('id','<>',$id)->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemInfo = db("page")->where('id','<>',$id)->where('url_name',$urlName)->find();
        if ($itemInfo) {
            return resError('别名已存在，请重新输入');
        }
        db("page")->where('id',$id)->update(array(
            'title' => $title,
            'url_name' => $urlName,
            'keywords' => $keywords,
            'template' => $template,
            'description' => $description,
            'content' => htmlspecialchars($content),
        ));
        return resSuccess();
    }

    public static function getPageInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("page")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getPageList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = ($paramData["order"] ?? "asc") ?: "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("page");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $k => $v) {
                $itemList[$k]['content'] = htmlspecialchars_decode($itemList[$k]['content']);
                $itemList[$k]['url'] = Get("domain") . '/' . $v['url_name'] . '.html';
            }
        }
        return $itemList;
    }

    public static function countPage($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("page");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deletePage($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("page")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("page")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }
}
