<?php
namespace app\admin\content\search\service;


use app\common\service\CommonSearchService;

class SearchDiyService
{
    public static function addSearchDiy($paramData): array
    {
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError('请输入名称');
        }
        $itemInfo = db("search_diy")->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemId = db("search_diy")->insertGetId(array(
            'title' => $title,
        ));
        $itemInfo = self::getSearchDiyInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function batchAddSearchDiy($paramData): array
    {
        $keywords = $paramData["keywords"] ?? "";
        if ($keywords == "") {
            return resError('请输入关键词');
        }
        $keywordsArray = explode(',', $keywords);
        $tempArray = [];
        if ($keywordsArray) {
            foreach ($keywordsArray as $key => $value) {
                $value = trim($value);
                if (empty($value) || ($value == "")) continue;
                $tempArray[] = $value;
            }
        }
        $addIdsArray = [];
        if ($keywordsArray) {
            foreach ($tempArray as $key => $title) {
                $itemInfo = db("search_diy")->where('title',$title)->find();
                if (!$itemInfo) {
                    $itemId = db("search_diy")->insertGetId(array(
                        'title' => $title,
                    ));
                    $addIdsArray[] = $itemId;
                }
            }
        }
        return resSuccess($addIdsArray);
    }

    public static function updateSearchDiy($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        if (!$id) {
            return resError('缺少参数');
        }
        if (!$title) {
            return resError('请输入名称');
        }
        $itemInfo = db("search_diy")->where('id',$id)->find();
        if (!$itemInfo) {
            return resError('修改项不存在');
        }
        $itemInfo = db("search_diy")->where('id','<>',$id)->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        db("search_diy")->where('id',$id)->update(array(
            'title' => $title,
        ));
        return resSuccess();
    }

    public static function getSearchDiyInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("search_diy")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getSearchDiyList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = ($paramData["orderBy"] ?? "id") ?: "id";
        $order = ($paramData["order"] ?? "asc") ?: "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("search_diy");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        if (count($itemList) > 0) {
            foreach($itemList as $index => $item) {
                $item["keywords"] = $item["title"];
                $itemList[$index] = CommonSearchService::buildSearchUrl($item);
            }
        }
        return $itemList;
    }

    public static function countSearchDiy($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("search_diy");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deleteSearchDiy($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("search_diy")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("search_diy")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }
}
