<?php
namespace app\admin\content\search\service;


use app\admin\content\addons\service\AddonsService;
use app\common\service\CommonSearchService;

class SearchKeywordsService
{

    public static function addSearchKeywords($paramData): array
    {
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError('请输入名称');
        }
        $itemInfo = db("search_keywords")->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemId = db("search_keywords")->insertGetId(array(
            'title' => $title,
        ));
        /*插件*/
        $addonsInfo = AddonsService::getAddonsInfo("randSearchUrl");
        if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
            /*执行插件 返回url*/
            $class = '\\addons\\randSearchUrl\\service\\RandSearchUrlService';
            $addonsObj = new $class();
            $url = $addonsObj->updateSearchUrl($title,$itemId);
        }
        return resSuccess();
    }


    public static function batchAddSearchKeywords($paramData): array
    {
        $keywords = $paramData["keywords"] ?? "";
        if ($keywords == "") {
            return resError('请输入关键词');
        }
        $keywordsArray = explode(',', $keywords);
        $tempArray = [];
        if ($keywordsArray) {
            foreach ($keywordsArray as $key => $value) {
                $value = trim($value);
                if (empty($value) || ($value == "")) continue;
                $tempArray[] = $value;
            }
        }
        $addIdsArray = [];
        if ($keywordsArray) {
            foreach ($tempArray as $key => $title) {
                $itemInfo = db("search_keywords")->where('title',$title)->find();
                if (!$itemInfo) {
                    $itemId = db("search_keywords")->insertGetId(array(
                        'title' => $title,
                    ));
                    /*插件*/
                    $addonsInfo = AddonsService::getAddonsInfo("randSearchUrl");
                    if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
                        /*执行插件 返回url*/
                        $class = '\\addons\\randSearchUrl\\service\\RandSearchUrlService';
                        $addonsObj = new $class();
                        $url = $addonsObj->updateSearchUrl($title,$itemId);
                    }
                    $addIdsArray[] = $itemId;
                }
            }
        }
        return resSuccess($addIdsArray);
    }

    public static function getSearchKeywordsInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("search_keywords")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getSearchKeywordsList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = ($paramData["orderBy"] ?? "id") ?: "id";
        $order = ($paramData["order"] ?? "desc") ?: "desc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("search_keywords");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = [];
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        if (count($itemList) > 0) {
            foreach($itemList as $index => $item) {
                $item["keywords"] = $item["title"];
                $itemList[$index] = CommonSearchService::buildSearchUrl($item);
            }
        }
        return $itemList;
    }

    public static function countSearchKeywords($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("search_keywords");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deleteSearchKeywords($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("search_keywords")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("search_keywords")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }
}
