<?php
namespace app\admin\content\special\service;


class SpecialRelService
{

    public static function addSpecialRel($paramData): array
    {
        $specialId = intval($paramData["specialId"] ?? 0);
        $relType = $paramData["relType"] ?? "a";
        $itemIds = $paramData["itemIds"] ?? "";
        if ($specialId == 0) {
            return resError("specialId不能为空");
        }
        if ($itemIds == "") {
            return resError("关联项不能为空");
        }
        if (!db("special")->where("id",$specialId)->find()) {
            return resError("专题不存在");
        }
        $itemIdArray = explode(",", $itemIds);
        if (count($itemIdArray) > 0) {
            foreach ($itemIdArray as $key => $itemId) {
                $dbData = db("special_rel")->where("special_id",$specialId)->where("item_id",$itemId)->find();
                if (!$dbData) {
                    db("special_rel")->insert([
                        "special_id" => $specialId,
                        "item_id" => $itemId,
                        "rel_type" => $relType,
                    ]);
                }
            }
        }
        $count = db("special_rel")->where("special_id",$specialId)->count();
        db("special")->where("id",$specialId)->update(["rel_num" => $count]);

        return resSuccess();
    }

    public static function getSpecialRelInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("special_rel")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getSpecialRelList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $specialId = intval($paramData["specialId"] ?? 0);
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $relType = $paramData["relType"] ?? "a";
        $dbItemIdList = db("special_rel")->where("special_id",$specialId)->where("rel_type",$relType)->page($page,$limit)->order($orderBy,$order)->select();
        return $dbItemIdList;
    }

    public static function countSpecialRel($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $relType = $paramData["relType"] ?? "a";
        $specialId = intval($paramData["specialId"] ?? 0);
        $count = db("special_rel")->field("item_id")->where("special_id",$specialId)->where("rel_type",$relType)->count("*");
        return $count;
    }

    public static function removeSpecialRel($paramData) {
        $relType = $paramData["relType"] ?? "a";
        $specialId = intval($paramData["specialId"] ?? 0);
        if ($specialId == 0) {
            return resError("specialId不能为空");
        }
        $itemIds = $paramData["itemIds"] ?? "";
        if ($itemIds == "") {
            db("special_rel")->where("special_id",$specialId)->delete();
        } else {
            $itemIdArray = explode(",", $itemIds);
            if (count($itemIdArray) > 0) {
                foreach ($itemIdArray as $key => $itemId) {
                    db("special_rel")->where("special_id",$specialId)->where("rel_type",$relType)->where("item_id",$itemId)->delete();
                }
            }
        }
        $count = db("special_rel")->where("special_id",$specialId)->where("rel_type",$relType)->count("*");
        db("special")->where("id",$specialId)->update(["rel_num" => $count]);
        return resSuccess();
    }

    /*删除*/
    public static function deleteSpecialRel($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                db("special_rel")->where("id",$id)->delete();
            }
        }
        return resSuccess();
    }


    public static function saveSpecialRelSort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("special_rel")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }

}
