<?php
namespace app\admin\content\special\service;

use app\common\service\CommonSpecialService;
use pagination\Paginations;

class SpecialService
{

    public static function addSpecial($paramData): array
    {
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError("请输入专题名称");
        }
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $template = $paramData["template"] ?? "special.html";
        $templateDetail = $paramData["templateDetail"] ?? "specialDetail.html";
        $dbData = db("special")->where("title",$title)->find();
        if ($dbData) {
            return resError("名称已存在");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        $itemId = db("special")->insertGetId([
            "title" => $title,
            "keywords" => $keywords,
            "description" => $description,
            "url_name" => $urlName,
            "template" => $template,
            "templateDetail" => $templateDetail,
            "sort" => 0,
        ]);
        $itemInfo = self::getSpecialInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updateSpecial($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError("请输入专题名称");
        }
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $urlName = $paramData["urlName"] ?? "";

        $template = $paramData["template"] ?? "special.html";
        $templateDetail = $paramData["templateDetail"] ?? "specialDetail.html";
        $dbData = db("special")->where("id",$id)->find();
        if (!$dbData) {
            return resError("专题不存在");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        db("special")->where("id",$id)->update([
            "title" => $title,
            "keywords" => $keywords,
            "description" => $description,
            "url_name" => $urlName,
            "template" => $template,
            "templateDetail" => $templateDetail,
        ]);
        return resSuccess();
    }

    /*查询单个信息*/
    public static function getSpecialInfo($id) {
        $itemInfo = db("special")->where("id",$id)->find();
        $itemInfo = CommonSpecialService::buildSpecialUrl($itemInfo);
        return $itemInfo;
    }

    public static function getSpecialList($paramData) {

        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("special");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index] = CommonSpecialService::buildSpecialUrl($item);
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countSpecial($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("special");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $count = $dbSelect->count("*");
        return $count;
    }

    /*随机*/
    public static function getRandomSpecial(int $num): array {
        return db("special")->orderRaw('rand()')->limit($num)->select()->all();
    }

    /*删除*/
    public static function deleteSpecial($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                db("special")->where("id",$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function saveSpecialSort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("special")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }

}
