<?php
namespace app\admin\content\tag\service;

use app\common\service\CommonTagCategoryService;

class TagCategoryService
{

    public static function addTagCategory($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $seoTitle = $paramData["seoTitle"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $template = $paramData["template"] ?? "";
        $detailTemplate = $paramData["detailTemplate"] ?? "";
        if ($title == "") {
            return resError("名称不能为空");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        $dbInfo = db("tag_category")->where("url_name",$urlName)->find();
        if ($dbInfo) {
            return resError("分类别名：". $urlName . "已存在，请重新输入");
        }
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "seo_title" => $seoTitle,
            "keywords" => $keywords,
            "description" => $description,
            "template" => $template,
            "detail_template" => $detailTemplate,
        ];
        $itemId = db("tag_category")->insertGetId($data);
        $itemInfo = self::getTagCategoryInfo($itemId);
        $url = TagBuildUrlService::buildTagCategoryUrl($itemInfo);
        db("tag_category")->where("id",$itemId)->update([
            "sort" => $itemId,
            "url" => $url,
        ]);
        $itemInfo = self::getTagCategoryInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updateTagCategory($paramData) {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $urlName = $paramData["urlName"] ?? "";
        $seoTitle = $paramData["seoTitle"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $template = $paramData["template"] ?? "";
        $detailTemplate = $paramData["detailTemplate"] ?? "";
        if ($title == "") {
            return resError("名称不能为空");
        }
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "seo_title" => $seoTitle,
            "keywords" => $keywords,
            "description" => $description,
            "template" => $template,
            "detail_template" => $detailTemplate,
        ];
        db("tag_category")->where("id", $id)->update($data);
        return resSuccess();
    }


    public static function updateTagCategoryUrl(): array
    {
        /*更新所有站点地址*/
        $categoryArray = db("tag_category")->select()->all();
        if ($categoryArray) {
            foreach ($categoryArray as $index => $item) {
                $url = TagBuildUrlService::buildTagCategoryUrl($item);
                db("tag_category")->where("id", $item["id"])->update(["url" => $url]);
            }
        }
        return resSuccess();
    }
    /*查询单个信息*/
    public static function getTagCategoryInfo($id) {
        $itemInfo = db("tag_category")->where("id",$id)->find();
        if ($itemInfo) {
            $itemInfo["url"] = CommonTagCategoryService::getTagCategoryUrl($itemInfo);
        }
        return $itemInfo;
    }

    public static function getTagCategoryList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = ($paramData["orderBy"] ?? "sort") ?: "sort";
        $order = ($paramData["order"] ?? "asc") ?: "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("tag_category");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                /*前台下拉菜单需要*/
                $itemList[$index]["label"] = $item["title"];
                $itemList[$index]["value"] = $item["id"];
                $itemList[$index]["url"] = CommonTagCategoryService::getTagCategoryUrl($item);
            }
        }
        return $itemList;
    }


    /*查询总数*/
    public static function countTagCategory($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("tag_category");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $count = $dbSelect->count("id");
        return $count;
    }

    public static function deleteTagCategory($ids) {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $categoryInfo = self::getTagCategoryInfo($id);
                if (!$categoryInfo) {
                    return ["data" => "", "error" => "分类不存在"];
                }
                db("tag_category")->where("id", $id)->delete();
            }
        }
        return resSuccess();
    }

    public static function saveTagCategorySort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("tag_category")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }

}