<?php
namespace app\admin\content\tag\service;

use app\admin\content\statistics\service\StatisticsService;
use app\common\service\CommonTagCategoryService;
use app\common\service\CommonTagService;
use app\home\tag\service\TagCategoryHomeService;

class TagService
{
    public static function addTag($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $cid = intval($paramData["cid"] ?? 0);
        $urlName = $paramData["urlName"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $isBatch = (bool)(($paramData["isBatch"] ?? ""));

        $title = trim($title);
        $urlName = trim($urlName);
        if ($title == "") {
            return resError("标题不能为空");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        if ($keywords == "") {
            $keywords = $title;
        }
        if ($description == "") {
            $description = $title;
        }
        if ($cid == 0) {
            $index = $urlName[0];
            $categoryInfo = db("tag_category")->where("url_name",$index)->find();
            if ($categoryInfo) {
                $cid = $categoryInfo["id"];
            } else {
                $categoryInfo = db("tag_category")->where("url_name","other")->find();
                if ($categoryInfo) {
                    $cid = $categoryInfo["id"];
                }
            }
        }
        $tagInfo = db("tag")->where("title",$title)->find();
        if ($tagInfo) {
            if (!$isBatch) {
                return resError("标签已存在");
            } else {
                return resSuccess();
            }
        }
        $urlNameInfo = db("tag")->where("url_name",$urlName)->find();
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "cid" => $cid,
            "keywords" => $keywords,
            "description" => $description,
            "add_time" => time(),
        ];
        $itemId = db("tag")->insertGetId($data);
        if ($urlNameInfo) {
            db("tag")->where("id", $itemId)->update([
                "url_name" => $urlName . $itemId,
            ]);
        }
        $itemInfo = self::getTagInfo($itemId,[]);
        $url = TagBuildUrlService::buildTagUrl($itemInfo);
        db("tag")->where("id", $itemId)->update([
            "url" => $url,
        ]);
        $itemInfo = self::getTagInfo($itemId,[]);
        return resSuccess($itemInfo);
    }

    public static function updateTag($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $cid = intval($paramData["cid"] ?? 1);
        $urlName = $paramData["urlName"] ?? "";
        $keywords = $paramData["keywords"] ?? "";
        $description = $paramData["description"] ?? "";
        $title = trim($title);
        $urlName = trim($urlName);
        if ($title == "") {
            return resError("标题不能为空");
        }
        if ($urlName == "") {
            $urlName = getPinyin($title);
        }
        $urlNameInfo = db("tag")->where("id",'<>',$id)->where("url_name",$urlName)->find();
        if ($urlNameInfo) {
            return resError("别名已存在");
        }
        $data = [
            "title" => $title,
            "url_name" => $urlName,
            "cid" => $cid,
            "keywords" => $keywords,
            "description" => $description,
            "add_time" => time(),
        ];
        db("tag")->where("id", $id)->update($data);
        return resSuccess();
    }


    public static function updateTagUrl(): array
    {
        /*更新所有站点地址*/
        $itemList = db("tag")->select()->all();
        if ($itemList) {
            foreach ($itemList as $index => $item) {
                $url = TagBuildUrlService::buildTagUrl($item);
                db("tag")->where("id", $item["id"])->update(["url" => $url]);
            }
        }
        return resSuccess();
    }

    /*查询单个信息*/
    public static function getTagInfo($id, $paramItemInfo) {
        if (!$paramItemInfo) {
            $itemInfo = db("tag")->where("id",$id)->find();
        } else {
            $itemInfo = $paramItemInfo;
        }
        if (!$itemInfo) {
            return [];
        }
        if ($itemInfo["cid"] != 0) {
            $itemInfo["categoryInfo"] = TagCategoryService::getTagCategoryInfo($itemInfo["cid"]);;
        } else {
            $itemInfo["categoryInfo"] = CommonTagCategoryService::configDefaultCategoryInfo();
        }
        $itemInfo["url"] = CommonTagService::getTagUrl($itemInfo);
        return $itemInfo;
    }


    public static function getTagList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = ($paramData["orderBy"] ?? "id") ?: "id";
        $order = ($paramData["order"] ?? "asc") ?: "asc";
        $keywords = $paramData["keywords"] ?? "";
        $tags = $paramData["tags"] ?? "";
        $itemId = intval($paramData["itemId"] ?? 0);
        $relType = ($paramData["relType"] ?? "a") ?: "a";

        $itemList = [];
        if ($itemId == 0) {
            $dbSelect = db("tag");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
            }
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid",$cid);
            }
            if ($tags != "") {
                $tagsArray = explode(",",$tags);
                $itemList = $dbSelect->where("title","in",$tagsArray)->select()->all();
            } else {
                $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
            }
        } else {
            $tempTagRelList = db("tag_rel")->where("item_id",$itemId)->order("id","asc")->where("rel_type",$relType)->select()->all();
            $tagIdArray = [];
            if (count($tempTagRelList) > 0) {
                foreach ($tempTagRelList as $item) {
                    $tagIdArray[] = $item["tag_id"];
                }
            }
            if ($tagIdArray) {
                $itemList = db("tag")->where("id","in",$tagIdArray)->select()->all();
            }
	    }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                if ($item["cid"] != 0) {
                    $itemList[$index]["categoryInfo"] = TagCategoryService::getTagCategoryInfo($item["cid"]);
                } else {
                    $itemList[$index]["categoryInfo"] = CommonTagCategoryService::configDefaultCategoryInfo();
                }
                $itemList[$index]["url"] = CommonTagService::getTagUrl($itemList[$index]);
            }
        }
        return $itemList;
    }


    /*查询总数*/
    public static function countTag($paramData): int
    {
        $cid = intval($paramData["cid"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $itemId = intval($paramData["itemId"] ?? 0);
        $count = 0;
        if (!$itemId) {
            $dbSelect = db("tag");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title", "like", "%" . $keywords . "%");
            }
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid", $cid);
            }
            $count = $dbSelect->count("*");
        }
        return $count;
    }

    /*删除*/
    public static function deleteTag($ids): array
    {
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $tagInfo = db("tag")->where("id", $id)->find();
                if (!$tagInfo) {
                    return resError("标签不存在");
                }
                $status = db("tag")->where("id", $id)->delete();
                /*标签*/
                TagRelService::deleteTagRel(["tagId" => $id,"relType" => "a"]);
            }
        }
        /*ids*/
        db("tag_ids")->delete(true);
        db("tag")->chunk(1000, function($list) {
            if (count($list) > 0) {
                $idsArray = [];
                foreach ($list as $item) {
                    $idsArray[] = $item["id"];
                }
                $ids = implode(",", $idsArray);
                db("tag_ids")->insertGetId([
                    'ids' => $ids
                ]);
            }
        });
        StatisticsService::updateTagCount([]);
        return resSuccess();
    }

    public static function transferTag($paramData): array
    {
        $ids = $paramData["ids"] ?? "";
        $cid = intval($paramData["cid"] ?? 0);
        if ($ids == "") {
            return resError("ids参数不能为空");
        }
        $ids = explode(',',$ids);
        if (is_array($ids)) {
            foreach ($ids as $id){
                db("tag")->where('id',$id)->update(['cid' => $cid]);
            }
        }
        return resSuccess();
    }
    public static function updateIndexNumTag(): array
    {
        /*ids*/
        db("tag_ids")->delete(true);
        db("tag")->chunk(1000, function($list) {
            if (count($list) > 0) {
                $idsArray = [];
                foreach ($list as $item) {
                    $idsArray[] = $item["id"];
                }
                $ids = implode(",", $idsArray);
                db("tag_ids")->insertGetId([
                    'ids' => $ids
                ]);
            }
        });
        StatisticsService::updateTagCount([]);
        return resSuccess();
    }
}
