<?php
namespace app\admin\content\widget\service;

class WidgetAdService
{
    public static function getItemListByTag($tag): string
    {
        $tag = json_decode($tag,true);
        $name = $tag['name'] ?? '';
        $itemInfo = db("widget_ad")->where('name',$name)->find();
        return htmlspecialchars_decode($itemInfo['content']);
    }

    public static function addWidgetAd($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $name = $paramData["name"] ?? "";
        $content = $paramData["content"] ?? "";
        $info = $paramData["info"] ?? "";
        if (!$title) {
            return resError('请输入名称');
        }
        if (!$name) {
            return resError('请输入别名');
        }
        $itemInfo = db("widget_ad")->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemInfo = db("widget_ad")->where('name',$name)->find();
        if ($itemInfo) {
            return resError('别名已存在，请重新输入');
        }
        $itemId = db("widget_ad")->insertGetId(array(
            'title' => $title,
            'name' => $name,
            'content' => htmlspecialchars($content),
            'add_time' => time(),
            'info' => $info,
        ));
        $itemInfo = self::getWidgetAdInfo($itemId);
        return resSuccess($itemInfo);
    }

    public static function updateWidgetAd($paramData): array
    {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $name = $paramData["name"] ?? "";
        $content = $paramData["content"] ?? "";
        $info = $paramData["info"] ?? "";
        if (!$id) {
            return resError('缺少参数');
        }
        if (!$title) {
            return resError('请输入名称');
        }
        if (!$name) {
            return resError('请输入别名');
        }
        $itemInfo = db("widget_ad")->where('id',$id)->find();
        if (!$itemInfo) {
            return resError('修改项不存在');
        }
        $itemInfo = db("widget_ad")->where('id','<>',$id)->where('title',$title)->find();
        if ($itemInfo) {
            return resError('名称已存在，请重新输入');
        }
        $itemInfo = db("widget_ad")->where('id','<>',$id)->where('name',$name)->find();
        if ($itemInfo) {
            return resError('别名已存在，请重新输入');
        }
        db("widget_ad")->where('id',$id)->update(array(
            'title' => $title,
            'name' => $name,
            'content' => htmlspecialchars($content),
            'info' => $info,
        ));
        return resSuccess();
    }

    public static function getWidgetAdInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("widget_ad")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getWidgetAdList($paramData) {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "asc";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_ad");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        foreach ($itemList as $k => $v) {
            $itemList[$k]['content'] = htmlspecialchars_decode($itemList[$k]['content']);
        }
        return $itemList;
    }
    public static function countWidgetAd($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_ad");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deleteWidgetAd($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("widget_ad")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("widget_ad")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function changeWidgetAdHideStatus($paramData): array
    {
        $isHide = intval($paramData["is_hide"] ?? 0);
        $id = intval($paramData["id"] ?? 0);
        $itemInfo = db("widget_ad")->where('id',$id)->update(["is_hide" => $isHide]);
        return resSuccess();
    }

}