<?php
namespace app\admin\content\widget\service;

class WidgetFriendLinkRequestService
{


    public static function addWidgetFriendLinkRequest($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $url = $paramData["url"] ?? "";
        $description = $paramData["description"] ?? "";
        if ($title == "") {
            return resError('请输入名称');
        }
        if ($url == "") {
            return resError('请输入网址');
        }
        $id = db("widget_friend_link_request")->insertGetId(array(
            'title' => $title,
            'url' => $url,
            'description' => $description,
            'add_time' => time(),
        ));
        $itemInfo = self::getWidgetFriendLinkRequestInfo($id);
        return resSuccess($itemInfo);
    }

    public static function updateWidgetFriendLinkRequest($paramData) {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $url = $paramData["url"] ?? "";
        $description = $paramData["description"] ?? $title;
        if ($title == "") {
            return resError('请输入名称');
        }
        if ($url == "") {
            return resError('请输入网址');
        }
        if(!db("widget_friend_link_request")->where('id',$id)->find()) {
            return resError('友情链接不存在');
        }
        db("widget_friend_link_request")->where('id',$id)->update(['title' => $title, 'url' => $url, 'description' => $description]);

        return resSuccess();
    }

    public static function getWidgetFriendLinkRequestInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("widget_friend_link_request")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getWidgetFriendLinkRequestList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_friend_link_request");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        return $itemList;
    }

    public static function countWidgetFriendLinkRequest($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_friend_link_request");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }


    public static function deleteWidgetFriendLinkRequest($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("widget_friend_link_request")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("widget_friend_link_request")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function joinWidgetFriendLinkRequest($id): array
    {
        if (!$id) {
            return resError('缺少参数');
        }
        $itemInfo = db("widget_friend_link_request")->where('id',$id)->find();
        if (!$itemInfo) {
            return resError('操作项不存在');
        }
        $resData = WidgetFriendLinkService::addWidgetFriendLink(["title" => $itemInfo["title"],"url" => $itemInfo["url"],"description" => $itemInfo["description"]]);
        if ($resData["err"]) {
            return $resData;
        }
        self::deleteWidgetFriendLinkRequest($id);
        return resSuccess();
    }


}