<?php
namespace app\admin\content\widget\service;

class WidgetFriendLinkService
{
    public static function getItemListByTag($paramData) {
        $paramData = json_decode($paramData,true);
        $orderBy = $paramData["orderBy"] ?? 'sort';
        $order = $paramData["order"] ?? 'asc';
        $typeWhere = [];
        if (Get("ctr") == 'Index') {
            $typeWhere['link_type']  = ['=','index'];
        } else {
            $typeWhere['link_type']  = ['=','notIndex'];
        }
        $itemList = db("widget_friend_link")->where($typeWhere)->whereOr('link_type','all')->order($orderBy,$order)->select()->all();
        if ($itemList) {
        } else {
            $itemList = [];
        }
        return $itemList;
    }

    public static function addWidgetFriendLink($paramData): array
    {
        $title = $paramData["title"] ?? "";
        $url = $paramData["url"] ?? "";
        $description = $paramData["description"] ?? $title;
        $linkType = $paramData["linkType"] ?? "all";
        $viewType = $paramData["viewType"] ?? "all";
        if ($title == "") {
            return resError('请输入名称');
        }
        if ($url == "") {
            return resError('请输入网址');
        }
        $id = db("widget_friend_link")->insertGetId(array(
            'title' => $title,
            'url' => $url,
            'description' => $description,
            'link_type' => $linkType,
            'view_type' => $viewType,
            'add_time' => time(),
        ));
        db("widget_friend_link")->where("id",$id)->update(["sort" => $id]);
        $itemInfo = self::getWidgetFriendLinkInfo($id);
        return resSuccess($itemInfo);
    }

    public static function updateWidgetFriendLink($paramData) {
        $id = intval($paramData["id"] ?? 0);
        $title = $paramData["title"] ?? "";
        $url = $paramData["url"] ?? "";
        $description = $paramData["description"] ?? $title;
        $linkType = $paramData["linkType"] ?? "all";
        $viewType = $paramData["viewType"] ?? "all";
        if ($title == "") {
            return resError('请输入名称');
        }
        if ($url == "") {
            return resError('请输入网址');
        }
        if(!db("widget_friend_link")->where('id',$id)->find()) {
            return resError('友情链接不存在');
        }
        db("widget_friend_link")->where('id',$id)->update(['title' => $title, 'url' => $url, 'description' => $description, 'link_type' => $linkType, 'view_type' => $viewType]);

        return resSuccess();
    }

    public static function getWidgetFriendLinkInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("widget_friend_link")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getWidgetFriendLinkList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_friend_link");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        return $itemList;
    }
    public static function countWidgetFriendLink($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_friend_link");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deleteWidgetFriendLink($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("widget_friend_link")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("widget_friend_link")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function saveWidgetFriendLinkSort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("widget_friend_link")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }

    public static function changeWidgetFriendLinkHideStatus($paramData): array
    {
        $isHide = intval($paramData["is_hide"] ?? 0);
        $id = intval($paramData["id"] ?? 0);
        $itemInfo = db("widget_friend_link")->where('id',$id)->update(["is_hide" => $isHide]);
        return resSuccess();
    }

}