<?php
namespace app\admin\content\widget\service;


class WidgetNavService
{
    public static function getItemListByTag($tag)
    {
        $tag = json_decode($tag,true);
        return self::getWidgetNavList($tag);
    }

    public static function addWidgetNav($paramData): array
    {
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError('请输入标题');
        }
        $id = db("widget_nav")->insertGetId(array(
            'title' => $title,
            'url' => $paramData['url'] ?? "",
            'is_target' => intval($paramData['isTarget'] ?? 0),
            'nav_type' => $paramData['navType'] ?? "",
        ));
        db("widget_nav")->where("id",$id)->update(["sort" => $id]);
        $itemInfo = self::getWidgetNavInfo($id);
        return resSuccess($itemInfo);
    }

    public static function updateWidgetNav($paramData) {
        $title = $paramData["title"] ?? "";
        if ($title == "") {
            return resError('请输入标题');
        }
        db("widget_nav")->where('id',$paramData['id'])->update(array(
            'title' => $title,
            'url' => $paramData['url'] ?? "",
            'is_target' => intval($paramData['isTarget'] ?? 0),
            'nav_type' => $paramData['navType'] ?? "",
        ));
        return resSuccess();
    }

    public static function getWidgetNavInfo($id)
    {
        if (!$id) {
            return [];
        }
        $itemInfo = db("widget_nav")->where("id",$id)->find();
        if (!$itemInfo) {
            return [];
        }
        return $itemInfo;
    }

    public static function getWidgetNavList($paramData)
    {
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_nav");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $itemList = $dbSelect->page($page,$limit)->order($orderBy, $order)->select()->all();
        return $itemList;
    }
    public static function countWidgetNav($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        $dbSelect = db("widget_nav");
        if ($keywords != "") {
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
        }
        $total = $dbSelect->count("*");
        return $total;
    }

    public static function deleteWidgetNav($ids): array
    {
        if (!$ids) {
            return resError('缺少参数');
        }
        $idsArray = explode(",",$ids);
        if (count($idsArray) > 0) {
            foreach ($idsArray as $key => $id) {
                $itemInfo = db("widget_nav")->where('id',$id)->find();
                if (!$itemInfo) {
                    return resError('删除项不存在');
                }
                db("widget_nav")->where('id',$id)->delete();
            }
        }
        return resSuccess();
    }

    public static function saveWidgetNavSort($sortList): array
    {
        if (count($sortList) > 0) {
            foreach ($sortList as $key => $item) {
                db("widget_nav")->where("id", $item["id"])->update(["sort" => $item["sort"]]);
            }
        }
        return resSuccess();
    }
    public static function changeWidgetNavStatus($isNav): array
    {
        $isNav = intval($isNav);
        db("base_setting")->where("name", "isNav")->update(["data" => $isNav]);
        return resSuccess();
    }

}
