<?php
namespace app\admin\user\service;

use think\facade\Cache;
use think\facade\Db;

class UserService
{

    public static function login(array $paramData): array
    {
        $username = $paramData['username'] ?? "";
        if ($username == "") {
            return resError("用户名不能为空");
        }
        $password = $paramData['password'] ?? "";
        if ($password == "") {
            return resError("密码不能为空");
        }
        $adminInfo = Db::table("base_admin")->where("username",$username)->find();
        if (!$adminInfo) {
            return resError("用户不存在");
        }
        $check = self::check_login_attempts($username);
        if ($check !== true) {
            return resError("登录次数过多，请5分钟之后再次尝试");
        }
        $md5Password = md5($password . $adminInfo["salt"]);
        if ($adminInfo["password"] != $md5Password) {
            self::record_failed_attempt($username);
            return resError("密码错误");
        }
        $adminInfo["password"] = "";
        $adminInfo["salt"] = "";
        $token = makeToken((int)$adminInfo['uid']);
//        Db::table('base_admin_token')->where('uid',$adminInfo["uid"])->delete();
        Db::table("base_admin_token")->InsertGetId([
            "token" => $token,
            "uid" => $adminInfo["uid"],
            "add_time" => time(),
        ]);
        Cache::set("login_attempts_{$username}", 0);
//        Cache::set($token, $adminInfo, 86400 * 7);
        return resSuccess($token);
    }

    public static function logout(): bool
    {
        $token = request()->header('Access-Token');
        if ($token) {
            Db::table("base_admin_token")->where("token",$token)->delete();
//            Cache::delete($token);
        }
        return true;
    }

    public static function checkLogin($token): array
    {
        if (!$token) {
            return resError("尚未登录，请重新登录");
        }
        $tokenInfo = Db::table("base_admin_token")->where("token",$token)->find();
        if (!$tokenInfo) {
            return resError("登录信息不存在，请重新登录");
        }
        $adminExpirationTime = config("global.adminExpirationTime");
        if ($tokenInfo["add_time"] + $adminExpirationTime < time()) {
            return resError("登录信息已过期，请重新登录");
        }
        $adminInfo = Db::table('base_admin')->where('uid',$tokenInfo["uid"])->find();
        if (!$adminInfo) {
            return resError("用户不存在");
        }
        $adminInfo["password"] = "";
        $adminInfo["salt"] = "";
        return resSuccess($adminInfo);
    }

    public static function getCurrentUserInfo(): array
    {
        $token = request()->header('Access-Token');
        if ($token) {
            $tokenInfo = Db::table("base_admin_token")->where("token",$token)->find();
            if ($tokenInfo) {
                $userInfo = Db::table("base_admin")->where("uid",$tokenInfo["uid"])->find();
                if ($userInfo) {
                    $userInfo["password"] = "";
                    $userInfo["salt"] = "";
                    return $userInfo;
                }
            }
//            return (array) Cache::get($token);
        }
        return [];
    }

    private static function check_login_attempts($username) {
        // 获取当前的尝试次数
        $attempts = Cache::get("login_attempts_{$username}");

        if ($attempts === false) {
            // 如果没有尝试次数记录，设置为0
            $attempts = 0;
        }

        if ($attempts >= 5) {
            // 如果尝试次数超过5次，检查是否应该解锁
            $unlock_time = Cache::get("lockout_{$username}");
            if ($unlock_time > time()) {
                // 如果还在锁定时间内，返回错误
                return false;
            } else {
                // 如果超出锁定时间，重置尝试次数
                Cache::set("login_attempts_{$username}", 0);
            }
        }

        return true;
    }

    private static function record_failed_attempt($username) {
        // 获取当前的尝试次数
        $attempts = Cache::get("login_attempts_{$username}") ?: 0;
        $attempts++;

        // 更新尝试次数
        Cache::set("login_attempts_{$username}", $attempts);
        if ($attempts >= 5) {
            // 如果尝试次数超过5次，设置锁定时间为当前时间加5分钟
            Cache::set("lockout_{$username}", time() + 5 * 60);
        }
    }
}