<?php
declare (strict_types = 1);
namespace app\common\controller;

use app\admin\system\service\SystemService;
use app\common\service\CommonArticleCategoryService;
use app\home\addons\service\AddonsHomeService;
use app\home\setting\service\SettingHomeService;
use think\App;
use think\facade\Db;
use think\facade\Route;
use think\facade\View;

/**
 * 控制器基础类
 */
class ApiBase
{

    /**
     * Request实例
     * @var \think\Request
     */
    protected $request;

    /**
     * 应用实例
     * @var \think\App
     */
    protected $app;
    /**
     * @var mixed
     */

    protected $addonsInfo;

    protected $globalAddonsList;
    /**
     * 构造方法
     * @access public
     * @param  App  $app  应用对象
     */
    public function __construct(App $app)
    {
        $this->app     = $app;
        $this->request = $this->app->request;
        // 控制器初始化
        $this->initialize();
    }

    /*初始化*/
    protected function initialize()
    {
        hook('addons.test.auto', ['id'=>1]);

        $this->initSystem();
    }

    private function initSystem() {
        $siteInfo = Get("siteInfo");
        $siteId = $siteInfo["id"];
        Set("siteId",$siteId);

        /*系统设置*/
        $systemInfo = SystemService::getSystemInfo();
        View::assign("systemInfo",$systemInfo);

        /*站点设置*/
        $settingInfo = SettingHomeService::getSettingData();
        /*模板*/
        $template = $settingInfo["template"];

        $isCMS = Get("isCMS");
        if ($isCMS) {
            /*域名*/
            $domain = $this->request->domain();
            if ($systemInfo["rewrite"]) {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"];
                }
            } else {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"] . "/index.php?s=";
                }
            }
        } else {
            /*域名*/
            if ($systemInfo["rewrite"]) {
                $domain = $siteInfo["web_url"];
            } else {
                $domain = $siteInfo["web_url"] . "/index.php?s=";
            }
        }

        /*模板*/
        $this->tplName = $template;
        View::assign("tplName",$template);

        /*域名*/
        View::assign("domain",$domain);
        Set("domain",$domain);

        /*静态域名*/
        $domainStatic = str_replace('/index.php?s=', '', $domain);
        View::assign("domainStatic",$domainStatic);
        Set("domainStatic",$domainStatic);

        /*当前url*/
        $currentUrl = $domainStatic . $this->request->url();
        View::assign("currentUrl",$currentUrl);

        /*插件*/
        $addonsInfo = AddonsHomeService::getAddonsData();
        $this->addonsInfo = $addonsInfo;
        Set("addonsInfo",$addonsInfo);
        View::assign("addonsInfo",$addonsInfo);

        /*数据*/
        $keyInfo = SettingHomeService::getKeyData();
        View::assign("keyInfo",$keyInfo);
        Set("keyInfo",$keyInfo);
        View::assign("keyInfo",$keyInfo);

        /*控制器*/
        View::assign('ctr',"");
        View::assign('act',"");

        View::assign('categoryUrlName',"");
        view::assign("categoryInfo",["id" => 0]);

        $tagUrlName = config("global.tagUrlName");
        if ($tagUrlName == "") {
            $tagUrlName = "tag";
        }
        view::assign("tagUrlName",$tagUrlName);
    }

}
