<?php
declare (strict_types = 1);
namespace app\common\controller;

use app\admin\content\domain\service\DomainService;
use app\admin\system\service\SystemService;
use app\common\service\CommonArticleCategoryService;
use app\home\addons\service\AddonsHomeService;
use app\home\article\service\ArticleCategoryHomeService;
use app\home\setting\service\SettingHomeService;
use app\home\setting\service\SystemHomeService;
use app\home\spider\service\SpiderService;
use think\App;
use think\facade\Db;
use think\facade\Route;
use think\facade\View;

/**
 * 控制器基础类
 */
class HomeBase
{

    /**
     * Request实例
     * @var \think\Request
     */
    protected $request;

    /**
     * 应用实例
     * @var \think\App
     */
    protected $app;
    /**
     * @var mixed
     */
    private $tplName;

    protected $addonsInfo;

    protected $globalAddonsList;
    /**
     * 构造方法
     * @access public
     * @param  App  $app  应用对象
     */
    public function __construct(App $app)
    {
        $this->app     = $app;
        $this->request = $this->app->request;
        // 控制器初始化
        $this->initialize();
    }

    /*初始化*/
    protected function initialize()
    {
        hook('addons.test.auto', ['id'=>1]);

        $this->initSystem();
        $this->initTemplate();
        $this->initArticleCategory();
        $this->spider();
        $this->initGlobalAddons();
    }

    private function initSystem() {
        $siteInfo = Get("siteInfo");
        $siteId = $siteInfo["id"];
        Set("siteId",$siteId);

        /*系统设置*/
        $systemInfo = SystemService::getSystemInfo();
        View::assign("systemInfo",$systemInfo);

        /*站点设置*/
        $settingInfo = SettingHomeService::getSettingData();
        /*模板*/
        $template = $settingInfo["template"];

        $isCMS = Get("isCMS");
        if ($isCMS) {
            /*域名*/
            $domain = $this->request->domain();
            if ($systemInfo["rewrite"]) {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"];
                }
            } else {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"] . "/index.php?s=";
                }
            }
        } else {
            /*域名*/
            if ($systemInfo["rewrite"]) {
                $domain = $siteInfo["web_url"];
            } else {
                $domain = $siteInfo["web_url"] . "/index.php?s=";
            }
        }

        Set("subDomainData",[]);
        /*启用多域名设置的信息覆盖*/
        if ($siteInfo) {
            $currentHost = Get("currentHost");
            $subSiteDomainInfo = db("base_domain")->where("domain",$currentHost)->find();
            if (isset($subSiteDomainInfo["data"]) && $subSiteDomainInfo["data"]) {
                $subDomainData = json_decode($subSiteDomainInfo["data"],true);
                Set("subDomainData",$subDomainData);
                foreach ($subDomainData as $key => $val) {
                    $settingInfo[$key] = $val;
                }
                if (isset($subDomainData["template"]) && $subDomainData["template"] != "") {
                    $template = $subDomainData["template"];
                }
                $domain = $subSiteDomainInfo["http_type"] . $subSiteDomainInfo["domain"];
            }
        }
        View::assign("settingInfo",$settingInfo);
        /*模板*/
        $this->tplName = $template;
        View::assign("tplName",$template);

        /*域名*/
        View::assign("domain",$domain);
        Set("domain",$domain);

        $isTagDomain = request()->__get("isTagDomain");
        $tagDomainUrlName = request()->__get("tagDomainUrlName");
        if ($isTagDomain && $tagDomainUrlName) {
            $currentHost = Get("currentHost");
            $currentScheme = Get("currentScheme");
            $domain = $currentScheme . "://". $currentHost;
            View::assign("domain",$domain);
            Set("domain",$domain);
        }

        $isCityDomain = request()->__get("isCityDomain");
        $cityDomainUrlName = request()->__get("cityDomainUrlName");
        if ($isCityDomain && $cityDomainUrlName) {
            $currentHost = Get("currentHost");
            $currentScheme = Get("currentScheme");
            $domain = $currentScheme . "://". $currentHost;
            View::assign("domain",$domain);
            Set("domain",$domain);
        }
        $cityInfo = Get("cityInfo");
        View::assign("cityInfo",$cityInfo);

        /*静态域名*/
        $domainStatic = str_replace('/index.php?s=', '', $domain);
        View::assign("domainStatic",$domainStatic);
        Set("domainStatic",$domainStatic);

        /*当前url*/
        $currentUrl = $domainStatic . $this->request->url();
        View::assign("currentUrl",$currentUrl);

        /*插件*/
        $addonsInfo = AddonsHomeService::getAddonsData();
        $this->addonsInfo = $addonsInfo;
        Set("addonsInfo",$addonsInfo);
        View::assign("addonsInfo",$addonsInfo);

        /*数据*/
        $keyInfo = SettingHomeService::getKeyData();
        View::assign("keyInfo",$keyInfo);
        Set("keyInfo",$keyInfo);
        View::assign("keyInfo",$keyInfo);

        /*控制器*/
        View::assign('ctr',"");
        View::assign('act',"");

        View::assign('categoryUrlName',"");
        view::assign("categoryInfo",["id" => 0]);

        $tagUrlName = config("global.tagUrlName");
        if ($tagUrlName == "") {
            $tagUrlName = "tag";
        }
        view::assign("tagUrlName",$tagUrlName);
    }


    private function initTemplate() {
//        $view = config("view");
//        $view["view_dir_name"] = "template/default/html";
//        config($view,"view");
        View::config(['view_dir_name' => 'template/' . $this->tplName . '/html']);

        $appDir = ROOT_PATH . "app" . DS . "home" . DS;
        $appDirPathArray = fetch_dir($appDir);
        $taglibArray = [];
        if (count($appDirPathArray) > 0) {
            foreach ($appDirPathArray as $k => $v) {
                $fileArray = explode(DS, $v);
                $appName = $fileArray[count($fileArray) - 1];
                $dirPath = $v . DS . "taglib";
                $filePath = $dirPath . DS . "Tag.php";
                if (is_dir($dirPath) &&  file_exists($filePath)) {
                    $taglibArray[] = "app\home\\" . $appName . "\\taglib\\Tag";
                }
            }
        }
        /*addons*/
        $addonsDir = ROOT_PATH . "addons" . DS;
        $addonsDirPathArray = fetch_dir($addonsDir);
        if (count($addonsDirPathArray) > 0) {
            foreach ($addonsDirPathArray as $k => $v) {
                $fileArray = explode(DS, $v);
                $appName = $fileArray[count($fileArray) - 1];
                $dirPath = $v . DS . "taglib";
                $filePath = $dirPath . DS . "Tag.php";
                if (is_dir($dirPath) &&  file_exists($filePath)) {
                    $taglibArray[] = "addons\\" . $appName . "\\taglib\\Tag";
                }
            }
        }
        View::config(['taglib_pre_load' => implode(",",$taglibArray)]);
        View::config(['default_filter' => '']);
    }

    private function initArticleCategory() {
        CommonArticleCategoryService::init();
    }

    private function spider() {
        SpiderService::addSpider([]);
    }

    private function initGlobalAddons() {
        $addonsDir = ROOT_PATH . "addons" . DS;
        $addonsDirPathArray = fetch_dir($addonsDir);
        if (count($addonsDirPathArray) > 0) {
            foreach ($addonsDirPathArray as $k => $v) {
                $fileArray = explode(DS, $v);
                $appName = $fileArray[count($fileArray) - 1];
                $dirPath = $v . DS . "controller";
                $filePath = $dirPath . DS . "GlobalAction.php";
                if (is_dir($dirPath) &&  file_exists($filePath)) {
                    $className = "addons\\" . $appName . "\\controller\\GlobalAction";
                    $this->globalAddonsList[] = $className;
//                    try {
                        $addons = new $className();
                        if ($addons->index() === false) {

                        }
//                    } catch (\Exception $e) {
//
//                    }
                }
            }
        }
    }

    protected function viewFetch($path) :string {
        if ($this->globalAddonsList && is_array($this->globalAddonsList) && count($this->globalAddonsList) > 0) {
            foreach ($this->globalAddonsList as $globalAddonsName) {
                try {
                    $addons = new $globalAddonsName();
                    $addons->fetchBefore();
                } catch (\Exception $e) {
                    continue;
                }
            }
        }
        $html = View::fetch($path);
        if ($this->globalAddonsList && is_array($this->globalAddonsList) && count($this->globalAddonsList) > 0) {
            foreach ($this->globalAddonsList as $globalAddonsName) {
                try {
                    $addons = new $globalAddonsName();
                    $html = $addons->fetchAfter($html);
                } catch (\Exception $e) {
                    continue;
                }
            }
        }
        return $html;
    }
}
