<?php


namespace app\common\service;


use think\facade\Config;
use think\facade\Db;

class CommonArticleCategoryService
{
    static $articleCategoryAllList = [];
    public static function init()
    {
        $categoryList = db("article_category")->order("sort","asc")->select()->all();
        if (count($categoryList) > 0) {
            self::$articleCategoryAllList = $categoryList;
        }
    }
    public static function getCategoryInfoByCache($id) {
        $articleCategoryAllList = self::$articleCategoryAllList;
        if (count($articleCategoryAllList) > 0) {
            foreach ($articleCategoryAllList as $item) {
                if ($item["id"] == $id) {
                    return $item;
                }
            }
        } else {
            /*当后台操作 没有进行init操作时使用数据库查询*/
            $categoryList = db("article_category")->order("sort","asc")->select()->all();
            if (count($categoryList) > 0) {
                foreach ($categoryList as $item) {
                    if ($item["id"] == $id) {
                        return $item;
                    }
                }
            }
        }
        return [];
    }


    public static function configDefaultCategoryInfo() {
        return [
            "id" => 0,
            "pid" => 0,
            "url_name" => "article",
            "title" => "文章",
            "keywords" => "",
            "description" => "",
            "url" => Get("domain") . "/article/",
            "template" => "articleCategory.html",
            "detail_template" => "articleDetail.html",
            "level" => 0,
            "children" => [],
            "parent" => [],
            "content" => "",
        ];
    }
    /*获取父级分类*/
    public static function getArticleCategoryParent($categoryInfo): array
    {
        $categoryInfo["parent"] = [];
        if ($categoryInfo['pid'] != 0) {
            $parentCategory = self::getCategoryInfoByCache($categoryInfo['pid']);
            if (count($parentCategory) > 0) {
                $parentCategory['content'] = htmlspecialchars_decode($parentCategory['content']);
                $parentCategory["url"] = CommonArticleCategoryService::getArticleCategoryUrl($parentCategory);
                $categoryInfo["parent"] = $parentCategory;

                if ($parentCategory["pid"] != 0) {
                    $parentParentCategory = self::getCategoryInfoByCache($parentCategory['pid']);
                    if (count($parentParentCategory) > 0) {
                        $parentParentCategory['content'] = htmlspecialchars_decode($parentParentCategory['content']);
                        $parentParentCategory["url"] = CommonArticleCategoryService::getArticleCategoryUrl($parentParentCategory);
                        $categoryInfo["parent"]["parent"] = $parentParentCategory;
                    } else {
                        /*脏数据*/
                        $categoryInfo["parent"]["parent"] = [];
                    }
                }
            } else {
                /*脏数据*/
                $categoryInfo["parent"] = [];
            }
        }
        return $categoryInfo;
    }
    /*获取子级分类*/
    public static function getLevelChildren($itemInfo) : array {

        $itemList = [];
        if (!empty($itemInfo["children_ids"])) {
            $childIdsArray = explode(",", $itemInfo["children_ids"]);
            if (count($childIdsArray) > 0) {
                foreach ($childIdsArray as  $id) {
                    $childInfo = self::getCategoryInfoByCache($id);

                    $childInfo['content'] = htmlspecialchars_decode($childInfo['content']);
                    $childInfo["urlData"] = $childInfo["url"];
                    $childInfo["url"] = CommonArticleCategoryService::getArticleCategoryUrl($childInfo);
                    /*级联菜单 列表展开*/
                    $childInfo["label"] = $childInfo["title"];
                    $childInfo["value"] = $childInfo["id"];
                    $childInfo["isOpen"] = true;
                    $childInfo["children"] = self::getLevelChildren($childInfo);
                    $itemList[] = $childInfo;
                }
            }
        } else {
            return [];
        }
        return $itemList;
    }

    /*获取url地址*/
    public static function getArticleCategoryUrl($categoryInfo) {
        return Get("domain") . $categoryInfo["url"];
    }

    public static function buildArticleCategoryRelIdsById($cid): array
    {
        $cidArray = [];
        $categoryInfo = CommonArticleCategoryService::getCategoryInfoByCache($cid);;
        if ($categoryInfo) {
            $cidArray[] = $cid;
            if ($categoryInfo["children_all_ids"] != "") {
                $childrenArray = explode(",", $categoryInfo["children_all_ids"]);
                $cidArray = array_merge($cidArray, $childrenArray);
            }
        }
        return $cidArray;
    }
}
