<?php

use scws\PSCWS4;
use think\facade\Db;
use think\facade\Route;
use think\facade\View;
use think\Response;
use think\Template;
use think\view\driver\Think;

use think\App;

function db($table) {
    $isCMS = Get("isCMS");
    if (!$isCMS) {
        $siteInfo = Get("siteInfo");
        if (!$siteInfo) {
            $siteInfo = request()->__get("siteInfo");
        }
        return Db::table($siteInfo["db_name"] . "." . $table);
    } else {
        return Db::table($table);
    }
}

function pageNotFound() {
    $addonsInfo = Get("addonsInfo");
    if ($addonsInfo && isset($addonsInfo["fml"]) && $addonsInfo["fml"]["is_disable"] == 0) {
        $fml = new \addons\fml\controller\FmlController(\app());
        return $fml->index();
    }

    if ($addonsInfo && isset($addonsInfo["pageNotFound"]) && $addonsInfo["pageNotFound"]["is_disable"] == 0) {
        $content = file_get_contents(ROOT_PATH . "addons" . DS . "pageNotFound" . DS . "view" . DS . "home" . DS . "pageNotFound.html" );
        $data = View::display($content);
        return Response::create($data,"html","404");
    } else {
        throw new \think\exception\HttpException(404, '页面不存在');
    }
}

function getCurrentSiteInfo() {
    $siteInfo = Get("siteInfo");
    if (!$siteInfo) {
        $siteInfo = request()->__get("siteInfo");
    }
    return $siteInfo;
}


function getDayTime() {
    return strtotime(date('Y-m-d'));
}

function getWords($title) {
    $pscws = new PSCWS4();
    $pscws->set_dict(ROOT_PATH . 'extend/scws/dict.utf8.xdb');
    $pscws->set_rule(ROOT_PATH . 'extend/scws/rules.utf8.ini');
    $pscws->set_ignore(true);
    $pscws->send_text($title);
    $keywordsData = $pscws->get_tops();
    $pscws->close();
    if (!$keywordsData) {
        $keywordsArray[] = $title;
    }
    if ($keywordsData) {
        foreach ($keywordsData as $key => $value) {
            $keywordsArray[] = $value['word'];
        }
    }
    return $keywordsArray;
}

function getKeywords($title = null,$content = null) {
    $pscws = new PSCWS4();
    $pscws->set_dict(ROOT_PATH . 'extend/scws/dict.utf8.xdb');
    $pscws->set_rule(ROOT_PATH . 'extend/scws/rules.utf8.ini');
    $pscws->set_ignore(true);
    $tempContent = deleteHtml($title . deleteHtml($content));
    $pscws->send_text($tempContent);
    $words = $pscws->get_tops(7);
    $pscwsTags = array();
    foreach ($words as $val) {
        $pscwsTags[$val['word']]= substr_count($tempContent,$val['word']);
    }
    $pscws->close();
    $tempKeywords = [];
    if ($pscwsTags) {
        arsort($pscwsTags);
        foreach ($pscwsTags as $key => $value) {
            $tempKeywords[] = $key;
        }
    }
    $keywords = implode(',', $tempKeywords);
    return $keywords;
}

function wordsreplace($content)
{
    $keywordsData = file_get_contents(ROOT_PATH . 'config' . DS . 'data' . DS . 'data.txt');
    if ($keywordsData) {
        $keywordsData = explode(PHP_EOL, $keywordsData);
        $tempData = [];
        foreach ($keywordsData as $key => $value) {
            $tempData[] = array('name' => $value ,'ishas' => false);
        }
        if ($tempData) {
            foreach ($tempData as $key => $value) {
                if ($value) {
                    $nameArray = explode(', ', $value['name']);
                    $name = $nameArray[0];
                    if (strpos($content, $name) !== false) {
                        $tempData[$key]['ishas'] = true;
                    }
                }
            }
            foreach ($tempData as $key => $value) {
                if ($value['ishas']) {
                    $nameArray = explode(', ', $value['name']);
                    $tempArray = [];
                    foreach ($nameArray as $k => $v) {
                        $name = trim($v);
                        if ($k > 0) {
                            $tempArray[] = $v;
                        }
                    }
                    $replaceName = $tempArray[array_rand($tempArray,1)];
                    foreach ($nameArray as $k => $v) {
                        $name = trim($v);
                        $content = str_replace($name, $replaceName, $content);
                    }
                }
            }
        }
    }
    return $content;
}


function getImgData($imgUrl,$htmlContent) {
    $imgUrlData = [];
    if ($htmlContent) {
        preg_match_all('/<img.*?src=[\'|\"](.*?)[\'|\"].*?[\/]?>/', $htmlContent, $imagesArrays);
        if (count($imagesArrays) > 0) {
            if (isset($imagesArrays[1][0])) {
                $imgUrlData[] = $imagesArrays[1][0];
            }
            if (isset($imagesArrays[1][1])) {
                $imgUrlData[] = $imagesArrays[1][1];
            }
            if (isset($imagesArrays[1][2])) {
                $imgUrlData[] = $imagesArrays[1][2];
            }
        }
    }
   if (!$imgUrl) {
       if (count($imgUrlData) > 0) {
           return ["img_url" => $imgUrlData[0],"img_url_data" => json_encode($imgUrlData,true)];
       } else {
           return ["img_url" => "","img_url_data" => ""];
       }
   } else {
       if (count($imgUrlData) > 0) {
           return ["img_url" => $imgUrl,"img_url_data" => json_encode($imgUrlData,true)];
       } else {
           return ["img_url" => $imgUrl,"img_url_data" => ""];
       }
   }
}

function htmlpurifier($html): string
{
    $config = HTMLPurifier_Config::createDefault();
    $purifier = new HTMLPurifier($config);
    return $purifier->purify($html);
}


if (!function_exists('hook')) {
    function hook($hookName, $params = null)
    {
        if (strpos($hookName, '.') !== false) {
            $hookNameArray = explode('.', $hookName);
            if ($hookNameArray[0] === "addons" && (isset($hookNameArray[1]) && $hookNameArray[1]) && (isset($hookNameArray[2]) && $hookNameArray[2])) {
                $modName = $hookNameArray[0];
                $className = $hookNameArray[1];
                $methodName = $hookNameArray[2];
                $hookFilePath = $modName . DS . $className . DS . "Hook.php";
                if (file_exists($hookFilePath)) {
                    $hookClass = "\\" . $modName . "\\" . $className . "\\Hook";
                    if (class_exists($hookClass) && method_exists($hookClass,$methodName)) {
                        return call_user_func($hookClass . "::" . $methodName,$params);
                    }
                }
            }
        }
        return "";
    }
}

function getLocalAllAddonsArray(): array {
    $addonsPath = root_path() . "addons" . DS;
    $dirNameAndPath = [];
    $files = [];
    if (is_dir($addonsPath)) {
        $files = glob($addonsPath . '*');
    }
    if (count($files) > 0) {
        foreach ($files as $file) {
            if (is_dir($file)) {
                $addonsPluginFile = $file . DS . "Addons.php";
                if (file_exists($addonsPluginFile)) {
                    $tempPathInfo = pathinfo($addonsPluginFile);
                    $dirName = pathinfo($tempPathInfo['dirname'], PATHINFO_FILENAME);
                    $pluginClass = "\\addons\\" . $dirName . "\\" . $tempPathInfo['filename'];
                    $pluginClassObj = new $pluginClass();
                    if ($dirName == $pluginClassObj->info["name"]) {
                        $dirNameAndPath[] = ["name" => $dirName,"path" => ROOT_PATH . "addons" . DS . $dirName . DS,"info" => $pluginClassObj->info];
                    }
                }
            }
        }
    }
    return $dirNameAndPath;
}

function getLocalContentAddonsArray(): array {
    $resArray = getLocalAllAddonsArray();
    $dirNameAndPath = [];
    if (count($resArray) > 0) {
        foreach ($resArray as $item) {
            if (strpos($item["name"],"global") === false) {
                $dirNameAndPath[] = $item;
            }

        }
    }
    return $dirNameAndPath;
}

function getLocalSiteAddonsArray(): array {
    $resArray = getLocalAllAddonsArray();
    $dirNameAndPath = [];
    if (count($resArray) > 0) {
        foreach ($resArray as $item) {
            if (strpos($item["name"],"global") === 0) {
                $dirNameAndPath[] = $item;
            }

        }
    }
    return $dirNameAndPath;
}


    // 检查并添加字段
    function checkAndAddColumn($siteInfo, $table, $column, $columnDefinition) {

        $tempDatabaseConfig = config("database")["connections"]["mysql"];

        /*获取数据库名称*/
        $dbName = $siteInfo["db_name"];
        $hostname = $tempDatabaseConfig["hostname"];
        $username = $tempDatabaseConfig["username"];
        $password = $tempDatabaseConfig["password"];
        $hostport = $tempDatabaseConfig["hostport"];

        $dsn = "mysql:dbname={$dbName};host={$hostname};port={$hostport};charset=utf8mb4";
        $options = [
            \PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true, // 启用查询缓冲
            \PDO::ATTR_ERRMODE => \PDO::ERRMODE_EXCEPTION // 启用异常模式
        ];

        try {
            $pdo = new \PDO($dsn, $username, $password, $options);
        } catch (\PDOException $e) {
            return resError("数据库连接失败：" . $e->getMessage());
        }

        $query = "SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = :dbName AND TABLE_NAME = :table AND COLUMN_NAME = :column";
        $stmt = $pdo->prepare($query);
        $stmt->execute([':dbName' => $pdo->query('select database()')->fetchColumn(), ':table' => $table, ':column' => $column]);
        $exists = $stmt->fetchColumn();
        if (!$exists) {
            $alterQuery = "ALTER TABLE `$table` ADD `$column` $columnDefinition";
            $pdo->exec($alterQuery);
        }
        return resSuccess();
    }
    // 检查并添加索引
     function checkAndAddIndex($siteInfo, $table, $indexName, $column) {
        $tempDatabaseConfig = config("database")["connections"]["mysql"];

        /*获取数据库名称*/
        $dbName = $siteInfo["db_name"];
        $hostname = $tempDatabaseConfig["hostname"];
        $username = $tempDatabaseConfig["username"];
        $password = $tempDatabaseConfig["password"];
        $hostport = $tempDatabaseConfig["hostport"];

        $dsn = "mysql:dbname={$dbName};host={$hostname};port={$hostport};charset=utf8mb4";
        $options = [
            \PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true, // 启用查询缓冲
            \PDO::ATTR_ERRMODE => \PDO::ERRMODE_EXCEPTION // 启用异常模式
        ];

        try {
            $pdo = new \PDO($dsn, $username, $password, $options);
        } catch (\PDOException $e) {
            return resError("数据库连接失败：" . $e->getMessage());
        }

        $query = "SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS WHERE TABLE_SCHEMA = :dbName AND TABLE_NAME = :table AND INDEX_NAME = :indexName";
        $stmt = $pdo->prepare($query);
        $stmt->execute([':dbName' => $pdo->query('select database()')->fetchColumn(), ':table' => $table, ':indexName' => $indexName]);
        $exists = $stmt->fetchColumn();

        if (!$exists) {
            $alterQuery = "ALTER TABLE `$table` ADD INDEX `$indexName` (`$column`)";
            $pdo->exec($alterQuery);
        }

        return resSuccess();
    }

    function checkAndRemoveColumn($siteInfo, $table, $column) {
        $tempDatabaseConfig = config("database")["connections"]["mysql"];

        /*获取数据库名称*/
        $dbName = $siteInfo["db_name"];
        $hostname = $tempDatabaseConfig["hostname"];
        $username = $tempDatabaseConfig["username"];
        $password = $tempDatabaseConfig["password"];
        $hostport = $tempDatabaseConfig["hostport"];

        $dsn = "mysql:dbname={$dbName};host={$hostname};port={$hostport};charset=utf8mb4";
        $options = [
            \PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true, // 启用查询缓冲
            \PDO::ATTR_ERRMODE => \PDO::ERRMODE_EXCEPTION // 启用异常模式
        ];

        try {
            $pdo = new \PDO($dsn, $username, $password, $options);
        } catch (\PDOException $e) {
            return resError("数据库连接失败：" . $e->getMessage());
        }
        $query = "SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = :dbName AND TABLE_NAME = :table AND COLUMN_NAME = :column";
        $stmt = $pdo->prepare($query);
        $stmt->execute([':dbName' => $pdo->query('select database()')->fetchColumn(), ':table' => $table, ':column' => $column]);
        $exists = $stmt->fetchColumn();

        if ($exists) {
            $alterQuery = "ALTER TABLE `$table` DROP COLUMN `$column`";
            $pdo->exec($alterQuery);
        }
        return resSuccess();
    }

    function getRandomStr($num) {
        if ($num == 0) {
            return "";
        } elseif ($num == 1) {
            $str_arr = array('a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z');
            $rand_index = array_rand($str_arr);
            return $str_arr[$rand_index];
        } else {
            $str_arr = 'abcdefghijklmnopqrstuvwxyz';
            $random_str = '';
            for ($i = 0; $i < $num; $i++) {
                $rand_index = mt_rand(0, strlen($str_arr) - 1);
                $random_str .= $str_arr[$rand_index];
            }
            return $random_str;
        }
    }


 function isSpider($userAgent) {
     $userAgent = strtolower($userAgent);
     $isSpider = false;
     if (strpos($userAgent,"spider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"baiduspider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"yisouspider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"sogou") !== false && strpos($userAgent,"spider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"360") !== false && strpos($userAgent,"spider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"bytespider") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"googlebot") !== false) {
         $isSpider = true;
     } else if (strpos($userAgent,"bingbot") !== false) {
         $isSpider = true;
     }
    return $isSpider;
}
