<?php


namespace app\home\article\service;


use app\admin\content\setting\service\UrlRuleService;

class ArticleCategoryCheckHomeService
{
    /*校验分类请求，URL是否符合规则*/
    public static function checkArticleCategoryUrl($paramData) {
        $routeOneLevelName = $paramData["routeOneLevelName"] ?? "";
        $routeTwoLevelName = $paramData["routeTwoLevelName"] ?? "";
        $routeThreeLevelName = $paramData["routeThreeLevelName"] ?? "";

        /*获取规则*/
        $urlRuleData = Get('urlRuleData');
        $articleCategoryRule = $urlRuleData["articleCategoryRule"];
        $articleCategoryLevelNum = $urlRuleData["articleCategoryLevelNum"];

        $data = [
            "oneLevelName" => $routeOneLevelName,
            "twoLevelName" => $routeTwoLevelName,
            "threeLevelName" => $routeThreeLevelName,
            "levelNum" => $articleCategoryLevelNum
        ];

        $requestUrl = request()->server()['REQUEST_URI'];
        $requestUrl = str_replace("/index.php?s=","",$requestUrl);
        $dbInfo = db("article_category")->where("url",$requestUrl)->find();
        if ($dbInfo) {
            return $dbInfo;
        }
        if (strpos($articleCategoryRule,'{c_url_name}') !== false) {
            return self::checkCategory($data, 'url_name');
        }
        if (strpos($articleCategoryRule,'{c_id}') !== false) {
            return self::checkCategory($data, 'id');
        }
        if (strpos($articleCategoryRule,'{c_title}') !== false) {
            return self::checkCategory($data, 'title');
        }
        return [];
    }
    /* 通用校验分类请求 */
    public static function checkCategory($data, $field): array {

        $categoryList = db("article_category")->field("id, pid, $field, level")->select()->all();
        if (empty($categoryList)) {
            return [];
        }
        // 构建 ID 到分类的映射
        $idCategoryData = [];
        foreach ($categoryList as $category) {
            $idCategoryData[$category["id"]] = $category;
        }
        return self::matchCategoryByLevel($data, $idCategoryData, $field);
    }

    /* 根据层级匹配分类 */
    private static function matchCategoryByLevel($data, $idCategoryData, $field) {
        $levelNum = $data["levelNum"];
        $oneLevelName = $data["oneLevelName"];
        $twoLevelName = $data["twoLevelName"];
        $threeLevelName = $data["threeLevelName"];

        $resData = [];
        if ($levelNum == 1) {
            if ($oneLevelName != "") {
                foreach ($idCategoryData as $key => $info) {
                    if ($info[$field] == $oneLevelName) {
                        $resData = $info;
                        break;
                    }
                }
            }
        }
        /*三级路由*/
        if ($levelNum == 2) {
            if ($threeLevelName != "") {
                $currentCategoryInfo = [];
                foreach ($idCategoryData as $key => $info) {
                    if ($info["level"] == 2 && $info[$field] == $threeLevelName) {
                        $currentCategoryInfo =  $info;
                        break;
                    }
                }
                /*检验三个层级是否为指定的值*/
                if ($currentCategoryInfo && ($idCategoryData[$currentCategoryInfo["pid"]][$field] == $twoLevelName) && ($idCategoryData[$idCategoryData[$currentCategoryInfo["pid"]]["pid"]][$field] == $oneLevelName)) {
                    $resData = $currentCategoryInfo;
                }
            } else {
                /*二级路由*/
                if ($twoLevelName != "") {
                    $currentCategoryInfo = [];
                    foreach ($idCategoryData as $key => $info) {
                        if ($info["level"] == 1 && $info[$field] == $twoLevelName) {
                            $currentCategoryInfo =  $info;
                            break;
                        }
                    }
                    if ($currentCategoryInfo && ($idCategoryData[$currentCategoryInfo["pid"]][$field] == $oneLevelName)) {
                        $resData = $currentCategoryInfo;
                    }
                } else {
                    /*一级路由*/
                    if ($oneLevelName != "") {
                        $currentCategoryInfo = [];
                        foreach ($idCategoryData as $key => $info) {
                            if ($info["level"] == 0 && $info[$field] == $oneLevelName) {
                                $currentCategoryInfo =  $info;
                                break;
                            }
                        }
                        if ($currentCategoryInfo && ($currentCategoryInfo["pid"] == 0)) {
                            $resData = $currentCategoryInfo;
                        }
                    }
                }
            }
        }

        return $resData;
    }


}