<?php
namespace app\home\article\service;

use app\common\service\CommonArticleCategoryService;
use think\facade\Db;

class ArticleCategoryHomeService
{
    /*查询分类单个信息*/
    public static function getArticleCategoryInfo($id): array
    {
        $itemInfo = [];
        if ($id == 0) {
            return CommonArticleCategoryService::configDefaultCategoryInfo();
        } else {
            $itemInfo = CommonArticleCategoryService::getCategoryInfoByCache($id);
            if (!$itemInfo) {
                return CommonArticleCategoryService::configDefaultCategoryInfo();
            }
            $itemInfo['content'] = htmlspecialchars_decode($itemInfo['content']);
            $itemInfo["url"] = CommonArticleCategoryService::getArticleCategoryUrl($itemInfo);
            $itemInfo["children"] = CommonArticleCategoryService::getLevelChildren($itemInfo);
            $itemInfo = CommonArticleCategoryService::getArticleCategoryParent($itemInfo);
        }
        return $itemInfo;
    }
    /*获取分类全部列表*/
    public static function getArticleCategorySitemapList($paramData) {
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $itemList = db("article_category")->order($orderBy,$order)->select()->all();
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index]["url"] = CommonArticleCategoryService::getArticleCategoryUrl($item);
            }
        }
        return $itemList;
    }
    /*获取分类列表*/
    public static function getArticleCategorylist($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $pid = intval($paramData["pid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "sort";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $ids = $paramData["ids"] ?? "";
        $itemList = [];
        if ($ids) {
            $tempArray = explode(',', $ids);
            $order = 'field(id,' . $ids . ')';
            $itemList = db("article_category")->where("id", "in", $tempArray)->order(Db::raw($order))->select()->all();
        } else {
            if ($orderBy == "sort" && $order == "asc") {
                $articleCategoryAllList = CommonArticleCategoryService::$articleCategoryAllList;
                if (count($articleCategoryAllList)) {
                    foreach ($articleCategoryAllList as $key => $val) {
                        if ($val["pid"] == $pid) {
                            $itemList[] = $val;
                        }
                    }
                }

             if ($itemList) {
                 if (count($itemList) > $limit) {
                     $itemList = array_slice($itemList, 0, $limit);
                 }
             }
            } else {
                $dbSelect = db("article_category")->where("pid", $pid);
                $itemList = $dbSelect->page($page, $limit)->order($orderBy, $order)->select()->all();
            }
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index] = self::getArticleCategoryInfo($item["id"]);
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countArticleCategory($paramData): int
    {
        $keywords = $paramData["keywords"] ?? "";
        if ($keywords == "") {
            if (CommonArticleCategoryService::$articleCategoryAllList) {
                $count = count(CommonArticleCategoryService::$articleCategoryAllList);
            } else {
                $dbSelect = db("article_category");
                $count = $dbSelect->count("*");
            }
        } else {
            $dbSelect = db("article_category");
            $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
            $count = $dbSelect->count("*");
        }
        return $count;
    }
}
