<?php
namespace app\home\article\service;

use addons\ranking\service\RankingService;
use app\common\service\CommonArticleCategoryService;
use app\common\service\CommonArticleService;
use app\home\special\service\SpecialHomeService;
use app\home\tag\service\TagHomeService;
use pagination\Pagination;
use pagination\PaginationDetail;
use think\facade\Db;

class ArticleHomeService
{

    protected static $homeArticleInfoList;

    /*查询单个信息*/
    public static function getArticleInfo($id,$itemInfo = null) {
        $itemInfo = [];
        if (!isset(self::$homeArticleInfoList[$id])) {
            if (!$itemInfo) {
                $itemInfo = db("article")->where("id",$id)->find();
            }
            if ($itemInfo) {
                $itemInfo["categoryInfo"] = ArticleCategoryHomeService::getArticleCategoryInfo($itemInfo["cid"]);;
                $itemInfo["url"] = CommonArticleService::getArticleUrl($itemInfo);

                if ($itemInfo["img_url"]) {
                    $itemInfo["firstImg"] = $itemInfo["img_url"];
                } else {
                    $itemInfo["firstImg"] = "/static/common/images/no-images.jpg";
                }
                self::$homeArticleInfoList[$id] = $itemInfo;
            }
        } else {
            $itemInfo = self::$homeArticleInfoList[$id];
        }
        if ($itemInfo) {
            return $itemInfo;
        }
        return [];
    }

    /*查询内容信息*/
    public static function getArticleContentInfo($itemInfo) {
        if ($itemInfo) {
            $itemContentInfo = db("article_content")->where("item_id",$itemInfo["id"])->find();
            $itemInfo["content"] = htmlspecialchars_decode($itemContentInfo["content"] ?? "");
            return $itemInfo;
        } else {
            return [];
        }
    }

    public static function getArticleList($paramData): array
    {
        $isRender = false;
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
            $isRender = true;
        }
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "desc";
        $keywords = $paramData["keywords"] ?? "";
        $tagId = intval($paramData["tagId"] ?? 0);
        $specialId = intval($paramData["specialId"] ?? 0);
        $tempType = $paramData["type"] ?? "";
        $isImg = $paramData["isImg"] ?? "";
        $ids = $paramData["ids"] ?? "";

        $itemList = [];
        /*缓存开始*/
//        $cacheKey = "articleList" . "_" . $cid . "_" .  $page . "_" . $limit  . "_" . $orderBy . "_" . $order . "_" . md5($keywords) . "_" . $tagId . "_" . $tempType . "_" . "$domain";
//        if ($isRender) {
//            $tempList = Cache::get($cacheKey);
//            if ($tempList) {
//                return $tempList;
//            }
//        }
        /*缓存结束*/

        if ($tempType == "") {
            $dbSelect = db("article");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title","like","%" . $keywords . "%");
            }
            if ($isImg != "") {
                $dbSelect = $dbSelect->where("img_url","<>","");
            }
            if ($cid != 0) {
                $tempArray = [];
                $tempArray = CommonArticleCategoryService::buildArticleCategoryRelIdsById($cid);
                $dbSelect = $dbSelect->where("cid","in",$tempArray);
            }
            $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        }
        if ($tempType == "search") {
            $itemList = ArticleSearchHomeService::getArticleSearchList($paramData);
        }
        if ($tempType == "rand") {
            $itemList = ArticleExtendHomeService::getArticleRandList($paramData);
        }
        if ($tempType == 'about') {
            $itemList = ArticleExtendHomeService::getArticleAboutList($paramData);
        }
        if ($tempType == 'love') {
            $itemList = ArticleExtendHomeService::getArticleLoveList($paramData);
        }
        if ($tempType == 'hot') {
            $dbSelect = db("article");
            if ($cid != 0) {
                $tempArray = CommonArticleCategoryService::buildArticleCategoryRelIdsById($cid);
                $dbSelect = $dbSelect->where("cid","in",$tempArray);
            }
            $itemList = $dbSelect->page($page,$limit)->order("views","desc")->select()->all();
        }
        $addonsInfo = Get("addonsInfo");
        $todayStartTime = time();
        if (isset($addonsInfo["ranking"]) && $addonsInfo["ranking"]["is_disable"] == 0) {
            $dbList = array();
            if ($tempType == 'day') {
                $dbList = db("addons_ranking")->field("item_id")->where('add_time','between',[$todayStartTime - (24 * 60 * 60) ,$todayStartTime])->select()->all();
            }
            if ($tempType == "week") {
                $dbList = db("addons_ranking")->field("item_id")->where('add_time','between',[$todayStartTime - (7 * 24 * 60 * 60) ,$todayStartTime])->select()->all();
            }
            if ($tempType == "month") {
                $dbList = db("addons_ranking")->field("item_id")->where('add_time','between',[$todayStartTime - (30 * 24 * 60 * 60) ,$todayStartTime])->select()->all();
            }
            $tempMap = [];
            if ($dbList) {
                foreach ($dbList as $key => $item) {
                    $itemId = intval($item["item_id"]);
                    if (isset($tempMap[$itemId])) {
                        $tempMap[$itemId] = intval($tempMap[$itemId]) + 1;
                    } else {
                        $tempMap[$itemId] = 1;
                    }
                }
                /*排序*/
                arsort($tempMap);
                $itemIdArray = array_keys($tempMap);
                /*分页得到具体数量的 ID切片*/
                $total = count($itemIdArray);
                $pageNum = intval(ceil($total / $limit));

                if ($page < 1) {
                    $page = 1;
                } elseif ($page > $pageNum) {
                    $page = $pageNum;
                }
                $startIndex = ($page - 1) * $limit; // 计算起始索引

                $lastItemIdArray = array_slice($itemIdArray, $startIndex, $limit);
                $itemList = [];
                /*根据项目ID得出项目列表*/
                if (count($lastItemIdArray) > 0) {
                    $dbSelect = db("article");
                    $itemList = $dbSelect->whereIn("id", $lastItemIdArray)->select()->all();
                }
            }
        }
        if ($tempType == 'recommend' || $tempType == 'top' || $tempType == 'elite') {
            $dbSelect = db("article");
            if ($cid != 0) {
                $tempArray = CommonArticleCategoryService::buildArticleCategoryRelIdsById($cid);
                $dbSelect = $dbSelect->where("cid","in",$tempArray);
            }
            if ($tempType == 'recommend') {
                $dbSelect = $dbSelect->where("is_recommend",1);
            }
            if ($tempType == 'top') {
                $dbSelect = $dbSelect->where("is_top",1);
            }
            if ($tempType == 'elite') {
                $dbSelect = $dbSelect->where("is_elite",1);
            }
            $itemList = $dbSelect->page($page,$limit)->order($orderBy,$order)->select()->all();
        }
        if ($tempType == "tag" && $tagId != 0) {
            $tempArray = [];
            $tempRelList = db("tag_rel")->where("tag_id",$tagId)->where("rel_type","a")->page($page,$limit)->order($orderBy,$order)->select()->all();
            if (count($tempRelList) > 0) {
                foreach ($tempRelList as $key => $item) {
                    $tempArray[] = $item["item_id"];
                }
                if (count($tempArray) > 0) {
                    $itemList = db("article")->where("id","in",$tempArray)->order($orderBy,$order)->select()->all();
                }
            }
        }

        if ($ids) {
            $tempArray = explode(',',$ids);
            $order= 'field(id,'.$ids.')';
            $itemList = db("article")->where("id","in",$tempArray)->order(Db::raw($order))->select()->all();
        }
        if ($tempType == "special" && $specialId != 0) {
            $tempArray = [];
            $tempRelList = db("special_rel")->where("special_id",$specialId)->where("rel_type","a")->page($page,$limit)->order("sort","asc")->select()->all();
            if (count($tempRelList) > 0) {
                foreach ($tempRelList as $key => $item) {
                    $tempArray[] = $item["item_id"];
                }
                if (count($tempArray) > 0) {
                    $ids = implode(",", $tempArray);
                    $order= 'field(id,'.$ids.')';
                    $itemList = db("article")->where("id","in",$tempArray)->order(Db::raw($order))->select()->all();
                }
            }
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index]["categoryInfo"] = ArticleCategoryHomeService::getArticleCategoryInfo($item["cid"]);;
                $itemList[$index]["url"] = CommonArticleService::getArticleUrl($item);
                if ($itemList[$index]["img_url"]) {
                    $itemList[$index]["firstImg"] = $itemList[$index]["img_url"];
                } else {
                    $itemList[$index]["firstImg"] = "/static/common/images/no-images.jpg";
                }
            }
        }
        /*缓存开始*/
//        $cacheKey = "articleList" . "_" . $cid . "_" .  $page . "_" . $limit  . "_" . $orderBy . "_" . $order . "_" . md5($keywords) . "_" . $tagId . "_" . $tempType . "_" . "$domain";
//        if ($isRender) {
//            Cache::set($cacheKey,$itemList,60);
//        }
        /*缓存结束*/
        return $itemList;
    }

    /*查询总数*/
    public static function countArticle($paramData): int
    {
        $cid = intval($paramData["cid"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $tempType = $paramData["type"] ?? "";
        $tagId = intval($paramData["tagId"] ?? 0);
        $specialId = intval($paramData["specialId"] ?? 0);
        if ($tempType == "tag" && $tagId != 0) {

        }
        if ($tempType == "special" && $specialId != 0) {

        }
        if (!$tagId) {
            $dbSelect = db("article");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title", "like", "%" . $keywords . "%");
            }
            if ($cid != 0) {
                $tempArray = CommonArticleCategoryService::buildArticleCategoryRelIdsById($cid);
                $dbSelect = $dbSelect->where("cid","in",$tempArray);
            }
            $count = $dbSelect->count("*");

        }
        return $count;
    }

    /*获取分页*/
    public static function getArticleListPage($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "desc";
        $keywords = $paramData["keywords"] ?? "";
        $tagId = intval($paramData["tagId"] ?? 0);
        $specialId = intval($paramData["specialId"] ?? 0);
        $tempType = $paramData["type"] ?? "";

        $html = "";
        if ($tempType == "") {
            $total = self::countArticle($paramData);
            $categoryInfo = ArticleCategoryHomeService::getArticleCategoryInfo($cid);
            $paginationArray = array(
                'base_url' => "",
                'total_rows' => $total,
                'per_page' => $limit,
                'cur_page' => $page,
            );
            $tempPathInfo = pathinfo($categoryInfo["url"]);
            $urlName = $tempPathInfo["basename"];
            if (strpos($urlName,".html") !== false) {
                $urlName = str_replace(".html","",$urlName);
                $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"];
                $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/";
                $paginationArray["prefix"] = $urlName . "_";
                $paginationArray["suffix"] = ".html";
            } else {
                $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                $paginationArray["prefix"] = "index_";
                $paginationArray["suffix"] = ".html";
            }
            $pagination = new Pagination($paginationArray);
            $html = $pagination->create_links();


//            $baseUrl = "";
//            $pagination_array = array(
//                'base_url' => $baseUrl,
//                'total_rows' => $total,
//                'per_page' => $limit,
//                'cur_page' => $page,
//                'page_break' => '_'
//            );
//            $pagination = new Paginationm($pagination_array);
//            $html = $pagination->create_links();
        }
        if ($tempType == "search") {
            $html = ArticleSearchHomeService::getArticleSearchPageList($paramData);
        }

        if ($tempType == "special" && $specialId != 0) {
            $total = db("special_rel")->where("special_id",$specialId)->where("rel_type","a")->count("*");
            $tagInfo = SpecialHomeService::getSpecialInfo($specialId,[]);
            if (!$tagInfo) {
                return "";
            }
            $baseUrl = Get("domain") . "/" . config("global.specialUrlName") . "/";
            $pagination_array = array(
                'first_url' => $tagInfo["url"],
                'base_url' => $baseUrl,
                "query_string_segment" => urlencode($tagInfo[config("global.tagUrlField")]),
                'page_break' => '_',
                'cur_page' => $page,
                'total_rows' => $total,
                'per_page' => $limit,
            );
            $pagination = new PaginationDetail($pagination_array);
            $html = $pagination->create_links();
        }
        if ($tempType == "tag" && $tagId != 0) {
            $total = db("tag_rel")->where("tag_id",$tagId)->where("rel_type","a")->count("*");
            $tagInfo = TagHomeService::getTagInfo($tagId,[]);
            if (!$tagInfo) {
                return "";
            }
            $paginationArray = array(
                'base_url' => "",
                'total_rows' => $total,
                'per_page' => $limit,
                'cur_page' => $page,
            );
            $tempPathInfo = pathinfo($tagInfo["url"]);
            $urlName = $tempPathInfo["basename"];
            if (strpos($urlName,".html") !== false) {
                $urlName = str_replace(".html","",$urlName);
                $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"];
                $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/";
                $paginationArray["prefix"] = $urlName . "_";
                $paginationArray["suffix"] = ".html";
            } else {
                $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                $paginationArray["prefix"] = "index_";
                $paginationArray["suffix"] = ".html";
            }
            $pagination = new Pagination($paginationArray);
            $html = $pagination->create_links();
        }
        return $html;
    }


    public static function getArticleDetailPage($paramData): array
    {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
            $isHome = true;
        }
        $cid = $paramData["cid"] ?? 0;
        $limit = $paramData["limit"] ?? 10;
        $itemId = $paramData["itemId"] ?? 0;
        $itemType = $paramData["itemType"] ?? "";

        $itemList = [];
        $dbSelect = db("article");
        if ($itemType == "upPage") {
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid",$cid);
            }
            $itemList = $dbSelect->where("id","<",$itemId)->order("id","desc")->limit($limit)->select()->all();
        }
        if ($itemType == "downPage") {
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid",$cid);
            }
            $itemList = $dbSelect->where("id",">",$itemId)->order("id","asc")->Limit($limit)->select()->all();
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $itemList[$index] = self::getArticleInfo(intval($item["id"]),$item);
            }
        }
        return $itemList;
    }

    public static function viewArticle($itemInfo) {
        $sessionId =  md5($itemInfo["id"] . session_id());
        $cacheInfo = db("article_cache")->where("cache_id", $sessionId)->find();
        if ($cacheInfo && intval($cacheInfo["add_time"]) + 60 > time()) {
            return;
        }
        $cacheList = db("article_cache")->order("id","desc")->limit(1)->select()->all();
        if (count($cacheList) > 0) {
            $cacheInfo = $cacheList[0];
            if (intval($cacheInfo["add_time"]) < getDayTime()) {
                db("article_cache")->where("add_time","<",getDayTime())->delete();
            }
        }
        db("article_cache")->where("cache_id", $sessionId)->delete();
        db("article_cache")->insertGetId([
            "cache_id" => $sessionId,
            "add_time" => time(),
        ]);
        db("article")->where("id", $itemInfo["id"])->update([
            "views" => intval($itemInfo["views"]) + 1,
        ]);
        $addonsInfo = Get("addonsInfo");
        if (isset($addonsInfo["ranking"]) && $addonsInfo["ranking"]["is_disable"] == 0) {
            RankingService::updateRanking($itemInfo["id"]);
        }
    }

}
