<?php
namespace app\home\search\service;

use app\common\service\CommonSearchService;
use pagination\PaginationDetail;
use pagination\Paginations;

class SearchHomeService
{

    public static function addSearchLog($paramData) {
        $keywords = $paramData["keywords"] ?? "";
        $id = db("search_log")->insertGetId(array(
            'title' => $keywords,
            'add_time' => time(),
            'ip' => request()->ip(),
        ));
        return resSuccess($id);
    }


    public static function addSearchKeywords($paramData):int {
        $keywords = $paramData["keywords"] ?? "";
        $id = 0;
        $dbInfo = db("search_keywords")->where("title",$keywords)->find();
        if (!$dbInfo) {
            $count = db("search_log")->where("title",$keywords)->count("*");
            $id = db("search_keywords")->insertGetId(array(
                'title' => $keywords,
                'search_num' => $count + 1,
            ));
        } else {
            $count = db("search_log")->where("title",$keywords)->count("*");
            db("search_keywords")->where("title",$keywords)->update(array(
                'search_num' => $count + 1,
            ));
            $id = $dbInfo["id"];
        }
        return $id;
    }

    public static function checkKeywords($paramData): bool
    {
        $keywords = $paramData["keywords"] ?? "";
        if ($keywords == "") {
            return false;
        }
        $keywordsList = db("search_intercept")->select()->all();
        $isHas = false;
        $keywordsId = intval($paramData["keywordsId"] ?? 0);
        if (count($keywordsList) > 0) {
            foreach ($keywordsList as $key => $val) {
                if (strpos($keywords,$val["title"]) !== false) {
                    $isHas = true;
                    /*更新日志中的状态*/
                    if ($keywordsId != 0) {
                        db("search_log")->where("id",$keywordsId)->update(["res_type" => "intercept"]);
                    }
                    break;
                }
            }
        }
        return $isHas;
    }

    public static function getSearchKeywordsList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "desc";
        $tempType = $paramData["type"] ?? "";
        $keywordsType = $paramData["keywordsType"] ?? "";

        if ($tempType == "") {
            if ($keywordsType == "diy") {
                $itemList = db("search_diy")->page($page, $limit)->order($orderBy, $order)->select()->all();
            } else {
                $itemList = db("search_keywords")->page($page, $limit)->order($orderBy, $order)->select()->all();
            }
        }
        if ($tempType == "rand") {
            if ($keywordsType == "diy") {
                $itemList = db("search_diy")->orderRaw('rand()')->limit($limit)->select()->all();
            } else {
                $itemList = db("search_keywords")->orderRaw('rand()')->limit($limit)->select()->all();
            }
        }
        $todayStartTime = time();
        $siteInfo = Get("siteInfo");
        if (!$siteInfo) {
            $siteInfo = request()->__get("siteInfo");
        }
        if ($tempType == "week") {
            $itemList = db("search_log")->alias('l')->join($siteInfo["db_name"] . "." . 'search_keywords k','l.title = k.title')->where("res_type","")->order("add_time", "desc")->where('add_time','between',[$todayStartTime - (7 * 24 * 60 * 60) ,$todayStartTime])->select()->all();
            $itemList = self::paginateAndDedupeData($itemList,$limit, $page);
        }
        if ($tempType == "month") {
            $itemList = db("search_log")->where("res_type","")->order("add_time", "desc")->where('add_time','between',[$todayStartTime - (30 * 24 * 60 * 60) ,$todayStartTime])->select()->all();
            $itemList = self::paginateAndDedupeData($itemList,$limit, $page);
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                $item["keywords"] = $item["title"];
                $itemList[$index] = CommonSearchService::buildSearchUrl($item);
            }
        }
        return $itemList;
    }

    private static function paginateAndDedupeData($data, $limit, $page) {
        // 对原始数据按照name值进行去重
        $dedupeData = [];
        foreach ($data as $item) {
            $name = $item['title'];
            if (!isset($dedupedData[$name])) {
                $dedupeData[$name] = $item;
            }
        }

        $totalPages = ceil(count($dedupeData) / $limit); // 计算总页数

        if ($page < 1) {
            $page = 1;
        } elseif ($page > $totalPages) {
            $page = $totalPages;
        }

        // 将去重后的数据转换为索引数组
        $dedupeData = array_values($dedupeData);

        $startIndex = ($page - 1) * $limit; // 计算起始索引

        // 使用array_slice函数截取一页的数据
        $pageData = array_slice($dedupeData, $startIndex, $limit);

        return $pageData;
    }
}
