<?php
namespace app\home\tag\service;

use app\common\service\CommonTagCategoryService;
use app\common\service\CommonTagService;
use app\home\tag\service\TagHomeExtendService;
use pagination\Pagination;
use pagination\PaginationDetail;
use pagination\Paginationm;
use think\facade\Db;

class TagHomeService
{
    /*查询单个信息*/
    public static function getTagInfo($id, $paramItemInfo) {
        if (!$paramItemInfo) {
            $itemInfo = db("tag")->where("id",$id)->find();
        } else {
            $itemInfo = $paramItemInfo;
        }
        if (!$itemInfo) {
            return [];
        }
        if ($itemInfo["cid"] != 0) {
            $itemInfo["categoryInfo"] = TagCategoryHomeService::getTagCategoryInfo($itemInfo["cid"]);;
        } else {
            $itemInfo["categoryInfo"] = CommonTagCategoryService::configDefaultCategoryInfo();
        }
        $itemInfo["url"] = CommonTagService::getTagUrl($itemInfo);
        return $itemInfo;
    }


    public static function getTagList($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $orderBy = $paramData["orderBy"] ?? "id";
        $order = $paramData["order"] ?? "asc";
        $keywords = $paramData["keywords"] ?? "";
        $itemId = intval($paramData["itemId"] ?? 0);
        $tempType = $paramData["type"] ?? "";
        $itemType = $paramData["itemType"] ?? "";
        $ids = $paramData["ids"] ?? "";
        $itemList = [];
        if ($tempType == "") {
            if ($itemId == 0) {
                if ($ids) {
                    $tempArray = explode(',',$ids);
                    $order= 'field(id,'.$ids.')';
                    $itemList = db("tag")->where("id","in",$tempArray)->order(Db::raw($order))->select()->all();
                } else {
                    $dbSelect = db("tag");
                    if ($keywords != "") {
                        $dbSelect = $dbSelect->where("title", "like", "%" . $keywords . "%");
                    }
                    if ($cid != 0) {
                        $dbSelect = $dbSelect->where("cid", $cid);
                    }
                    $itemList = $dbSelect->page($page, $limit)->order($orderBy, $order)->select()->all();
                }
            } else {
                $tempTagRelList = db("tag_rel")->where("item_id", $itemId)->where("rel_type",$itemType)->order("id", "asc")->select()->all();
                if (count($tempTagRelList) > 0) {
                    foreach ($tempTagRelList as $key => $item) {
                        $tempTagInfo = db("tag")->where("id", $item["tag_id"])->find();
                        if ($tempTagInfo) {
                            $itemList[] = $tempTagInfo;
                        }
                    }
                }
            }
        }
        if ($tempType == "rand") {
            $itemList = TagHomeExtendService::getTagRandList($paramData);
        }
        if (count($itemList) > 0) {
            foreach ($itemList as $index => $item) {
                if ($item["cid"] != 0) {
                    $itemList[$index]["categoryInfo"] = TagCategoryHomeService::getTagCategoryInfo($item["cid"]);;
                } else {
                    $itemList[$index]["categoryInfo"] = CommonTagCategoryService::configDefaultCategoryInfo();
                }
                $itemList[$index]["url"] = CommonTagService::getTagUrl($item);
            }
        }
        return $itemList;
    }

    /*查询总数*/
    public static function countTag($paramData): int
    {
        $cid = intval($paramData["cid"] ?? 0);
        $keywords = $paramData["keywords"] ?? "";
        $itemId = intval($paramData["itemId"] ?? 0);
        $count = 0;
        if (!$itemId) {
            $dbSelect = db("tag");
            if ($keywords != "") {
                $dbSelect = $dbSelect->where("title", "like", "%" . $keywords . "%");
            }
            if ($cid != 0) {
                $dbSelect = $dbSelect->where("cid", $cid);
            }
            $count = $dbSelect->count("*");
        }
        return $count;
    }

    /*获取分页*/
    public static function getTagListPage($paramData) {
        if (!is_array($paramData)) {
            $paramData = json_decode($paramData,true);
        }
        $cid = intval($paramData["cid"] ?? 0);
        $page = intval($paramData["page"] ?? 1);
        $limit = intval($paramData["limit"] ?? 10);
        $total = self::countTag($paramData);
        $paginationArray = array(
            'base_url' => "",
            'total_rows' => $total,
            'per_page' => $limit,
            'cur_page' => $page,
        );
        if ($cid != 0) {
            $categoryInfo = TagCategoryHomeService::getTagCategoryInfo($cid);
            if ($categoryInfo) {
                $tempPathInfo = pathinfo($categoryInfo["url"]);
                $urlName = $tempPathInfo["basename"];
                if (strpos($urlName,".html") !== false) {
                    $urlName = str_replace(".html","",$urlName);
                    $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"];
                    $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/";
                    $paginationArray["prefix"] = $urlName . "_";
                    $paginationArray["suffix"] = ".html";
                } else {
                    $paginationArray["first_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                    $paginationArray["base_url"] = $tempPathInfo["dirname"] . "/" . $tempPathInfo["basename"]. "/";
                    $paginationArray["prefix"] = "index_";
                    $paginationArray["suffix"] = ".html";
                }
            }
        }
        $pagination = new Pagination($paginationArray);
        $html = $pagination->create_links();
        return $html;
    }


}