<?php
namespace app\install\controller;

use app\BaseController;
use think\facade\View;
use think\Request;
use think\Db;

class Install extends BaseController
{
    public function index()
    {
        if (is_file(ROOT_PATH . "install" . DS .'install.lock')) {
            exit();
        }
        $data = array();
        //php版本、操作系统版本
        $data['phpversion'] = @phpversion();
        $data['os'] = PHP_OS;
        //环境检测
        $err = 0;
        if (class_exists('pdo')) {
            $data['pdo'] = '已开启';
        } else {
            $data['pdo'] = '未开启';
            $err++;
        }
        //扩展检测
        if (extension_loaded('pdo_mysql')) {
            $data['pdo_mysql'] = '已开启';
        } else {
            $data['pdo_mysql'] = '未开启';
            $err++;
        }
        if (extension_loaded('curl')) {
            $data['curl'] = '已开启';
        } else {
            $data['curl'] = '未开启';
            $err++;
        }
        if (extension_loaded('mbstring')) {
            $data['mbstring'] = '已开启';
        } else {
            $data['mbstring'] = '未开启';
            $err++;
        }
        if (extension_loaded('exif')) {
            $data['exif'] = '已开启';
        } else {
            $data['exif'] = '未开启';
            $err++;
        }
        //设置获取
        if (ini_get('file_uploads')) {
            $data['upload_size'] = ini_get('upload_max_filesize');
        } else {
            $data['upload_size'] = '禁止上传';
        }
        if (ini_get('allow_url_fopen')) {
            $data['allow_url_fopen'] = '已开启';
        } else {
            $data['allow_url_fopen'] = '未开启';
            $err++;
        }
        //函数检测
        if (function_exists('file_get_contents')) {
            $data['file_get_contents'] = '已开启';
        } else {
            $data['file_get_contents'] = '未开启';
            $err++;
        }
        if (function_exists('session_start')) {
            $data['session'] = '已开启';
        } else {
            $data['session'] = '未开启';
        }
        //检测文件夹属性
        $cache =  ROOT_PATH . 'runtime';
        $config = ROOT_PATH . 'app';
        $newChecklist = array();
        if (is_writable($cache)) {
            $newChecklist['cache']['w'] = true;
        } else {
            $newChecklist['cache']['w'] = false;
        }
        if (is_writable($config)) {
            $newChecklist['config']['w'] = true;
        } else {
            $newChecklist['config']['w'] = false;
        }
        $data['checklist'] = $newChecklist;
        View::assign('data',$data);
        $request = request();
        $installAddress = $request->domain() . $request->url();
        View::assign('installAddress',$installAddress);

        return View::fetch('/admin/install/install');
    }

    public function install()
    {
        if (is_file(ROOT_PATH . "install" . DS . 'install.lock')) {
            return jsonError('系统已安装');
        }
        if (!request()->isPost()) {
            return jsonError('请求方式错误');
        }
        $installInfo = input('post.installInfo/a');
        $dbConfig['hostport'] = $installInfo["port"];
        $dbConfig['hostname'] = $installInfo["host"];
        $dbConfig['database'] = $installInfo["dbName"];
        $dbConfig['username'] = $installInfo["dbUsername"];
        $dbConfig['password'] = $installInfo["dbPassword"];
        $dbConfig['type'] = 'mysql';
        $dbConfig['dsn'] = '';
        $dbConfig['params'] = [];
        $dbConfig['prefix'] = "";
        $dbConfig['charset'] = 'utf8mb4';
        $replaceArray['hostname'] = $dbConfig['hostname'];
        $replaceArray['hostport'] = $dbConfig['hostport'];
        $replaceArray['database'] = $dbConfig['database'];
        $replaceArray['username'] = $dbConfig['username'];
        $replaceArray['password'] = $dbConfig['password'];
        $username = $installInfo["username"];
        $password = $installInfo["password"];
        $rPassword = $installInfo["rPassword"];

        if (!$username) {
            return jsonError('请输入用户名');
        }
        if (!$password) {
            return jsonError('请输入密码');
        }
        if (!$rPassword) {
            return jsonError('请输入重复密码');
        }
        if ($password != $rPassword) {
            return jsonError('两次输入的密码不相等');
        }
        $dsn = "mysql:dbname={$dbConfig['database']};host={$dbConfig['hostname']};port={$dbConfig['hostport']};charset=utf8";
        try {
            $db = new \PDO($dsn, $dbConfig['username'], $dbConfig['password']);
        } catch (\Exception $e) {
            if (strpos($e->getMessage(),"Access denied for user") !== false) {
                return jsonError("数据库用户或密码错误，错误代码：" . $e->getMessage());
            }
            return jsonError('错误代码:'.$e->getMessage());
        }
        /*查看版本*/
        $dbVersion = $db->query("SELECT VERSION();")->fetchAll()[0][0];
        $dbPass = false;
        if (strpos($dbVersion,'5.7') !== false) {
            $dbPass = true;
        }
        if (strpos($dbVersion,'8.') !== false) {
            $dbPass = true;
        }
        if (!$dbPass) {
            return jsonError("暂不支持当前数据库版本：" . $dbVersion);
        }
        /*sql*/
        $content = file_get_contents(ROOT_PATH . 'config' . DS . "sql" . DS . 'data.sql');
        $content = str_replace("\r\n", "\n", $content);
        $content = str_replace("\r", "\n", $content);
        $sqlArray = explode(";\n", $content);
        try {
            foreach ($sqlArray as $sqlItemStr) {
                $sqlItemStr = trim($sqlItemStr);
                if (empty($sqlItemStr) || $sqlItemStr == "") continue;
                if (false === $db->exec($sqlItemStr. ";")) {
                    return jsonError('数据库安装失败,执行的SQL：' . $sqlItemStr);
                }
            }
        } catch (\Exception $e) {
            return jsonError("数据库安装失败 " . $e->getMessage());
        }
        /*写入数据库配置文件*/
        $conf = $this->getDbConfigContent();
        foreach ($replaceArray as $key => $value) {
            $conf = str_replace("#{$key}#", $value, $conf);
        }
        $configPath = ROOT_PATH . 'config' . DS;
        $installPath = ROOT_PATH . 'install' . DS;
        if (!is_writable($installPath)) {
            return jsonError('路径：' . $installPath . '没有写入权限');
        }
        if (!is_writable($configPath)) {
            return jsonError('路径：' . $configPath . '没有写入权限');
        }
        try {
            if (is_file($configPath . 'database.php')) {
              	unlink($configPath . 'database.php');
            }
            file_put_contents($configPath . 'database.php', $conf);
        } catch (\Exception $e) {
            return jsonError("database.php 文件写入失败，请检查 {$configPath} 文件夹是否可写入");
        }

        /*写入管理员账号密码*/
        $salt = create_salt(8);
        $mdPassword = create_md5($password,$salt);
        try {
            $tempConfig = [
                'default'         => "tempMysql",
                'time_query_rule' => [],
                'auto_timestamp'  => true,
                'datetime_format' => 'Y-m-d H:i:s',
                'datetime_field'  => '',
                'connections'     => [
                    'tempMysql' => [
                        'type'            => "mysql",
                        'hostname'        => $dbConfig['hostname'],
                        'database'        => $dbConfig['database'],
                        'username'        => $dbConfig['username'],
                        'password'        => $dbConfig['password'],
                        'hostport'        => $dbConfig['hostport'],
                        'params'          => [],
                        'charset'         => "utf8mb4",
                        'prefix'          => "",
                        'deploy'          => 0,
                        'rw_separate'     => false,
                        'master_num'      => 1,
                        'slave_no'        => '',
                        'fields_strict'   => true,
                        'break_reconnect' => false,
                        'trigger_sql'     => false,
                        'fields_cache'    => false,
                    ],
                ],
            ];
            $dbObj = new \think\DbManager();
            $dbObj->setConfig($tempConfig);
            $dbObj->table('base_admin')->insert(array(
                'uid' => uuid(),
                'username' => $username,
                'password' => $mdPassword,
                'salt' => $salt,
                'reg_time' => time(),
            ));
        } catch (\Exception $e) {
            return jsonError("管理员信息写入失败" . $e->getMessage());
        }
        /*写入锁定文件*/
        try {
            file_put_contents(ROOT_PATH . "install" . DS . 'install.lock', '');
        } catch (\Exception $e) {
        return jsonError("install.lock 文件写入失败，请检查 {$installPath} 文件夹是否可写入");
        }
        return jsonSuccess('安装完成','');
    }

    private function getDbConfigContent() {
        return "<?php

return [
    // 默认使用的数据库连接配置
    'default'         => env('database.driver', 'mysql'),

    // 自定义时间查询规则
    'time_query_rule' => [],

    // 自动写入时间戳字段
    // true为自动识别类型 false关闭
    // 字符串则明确指定时间字段类型 支持 int timestamp datetime date
    'auto_timestamp'  => true,

    // 时间字段取出后的默认时间格式
    'datetime_format' => 'Y-m-d H:i:s',

    // 时间字段配置 配置格式：create_time,update_time
    'datetime_field'  => '',

    // 数据库连接配置信息
    'connections'     => [
        'mysql' => [
            // 数据库类型
            'type'            => env('database.type', 'mysql'),
            // 服务器地址
            'hostname'        => env('database.hostname', '#hostname#'),
            // 数据库名
            'database'        => env('database.database', '#database#'),
            // 用户名
            'username'        => env('database.username', '#username#'),
            // 密码
            'password'        => env('database.password', '#password#'),
            // 端口
            'hostport'        => env('database.hostport', '#hostport#'),
            // 数据库连接参数
            'params'          => [],
            // 数据库编码默认采用utf8
            'charset'         => env('database.charset', 'utf8mb4'),
            // 数据库表前缀
            'prefix'          => env('database.prefix', ''),

            // 数据库部署方式:0 集中式(单一服务器),1 分布式(主从服务器)
            'deploy'          => 0,
            // 数据库读写是否分离 主从式有效
            'rw_separate'     => false,
            // 读写分离后 主服务器数量
            'master_num'      => 1,
            // 指定从服务器序号
            'slave_no'        => '',
            // 是否严格检查字段是否存在
            'fields_strict'   => true,
            // 是否需要断线重连
            'break_reconnect' => false,
            // 监听SQL
            'trigger_sql'     => env('app_debug', true),
            // 开启字段缓存
            'fields_cache'    => false,
        ],

        // 更多的数据库配置信息
    ],
];";
    }


}

