<?php
namespace app\middleware;

use app\admin\content\setting\service\SettingService;
use app\admin\system\service\SystemService;
use app\admin\user\service\UserService;
use app\home\setting\service\SettingHomeService;
use app\home\setting\service\SystemHomeService;
use think\App;
use think\facade\Db;
use think\Request;
use think\Response;

class AdminContentAuth
{
    protected $app;


    public function __construct(App $app)
    {
        $this->app  = $app;
    }

    public function handle(Request $request, \Closure $next)
    {
        /*判断当前是否是POST请求*/
        if (!$request->isPost()) {
            header('Content-type: application/json');
            exit(json_encode(array('code' => -1 ,'msg' => '非法请求'), JSON_UNESCAPED_UNICODE));
        }
        /*验证*/
        $token = request()->header('Access-Token');
        if ($token == "") {
            $token = input("post.accessToken");
        }
        $LoginData = UserService::checkLogin($token);
        if ($LoginData["err"]) {
            $return['msg'] = $LoginData["err"];
            $return['code'] = 401;
            return Response::create(json_encode($return,JSON_UNESCAPED_UNICODE))->contentType('text/json');
        }
        Set("adminInfo",$LoginData["data"]);
        /*站点开始*/
        $isCMS = Get("isCMS");
        if (!$isCMS) {
            /*判断是否有siteId*/
            $siteId = $request->header("Site-Id");
            if ($siteId == "") {
                $siteId = input("post.siteId");
            }
            if (!$siteId) {
                return Response::create(json_encode(array('code' => -1 ,'msg' => '请求参数错误，请联系软件提供商'), JSON_UNESCAPED_UNICODE))->contentType('text/json');
            }
            /*判断上传文件路径*/
            if (strpos($request->url(),config("global.adminUrl"). "/uploads/imgUpload") !== false) {
                $siteId = input("post.siteId");
            }
            /*查询当前站点的信息*/
            $siteInfo = Db::table("site")->where("id",$siteId)->find();
            if (!$siteInfo) {
                return Response::create(json_encode(array('code' => -1 ,'msg' => '站点不存在'), JSON_UNESCAPED_UNICODE))->contentType('text/json');
            }
            Set("siteInfo",$siteInfo);
            Set("siteId",$siteId);
            /*系统设置*/
            $mainSystemInfo = SystemService::getSystemInfo();
            /*域名*/
            if ($mainSystemInfo["rewrite"]) {
                $domain = $siteInfo["web_url"];
            } else {
                $domain = $siteInfo["web_url"] . "/index.php?s=";
            }
        } else {
            /*系统设置*/
            $systemInfo = SystemService::getSystemInfo();
            /*站点设置*/
            $settingInfo = SettingHomeService::getSettingData();
            /*域名*/
            $domain = $request->domain();
            if ($systemInfo["rewrite"]) {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"];
                }
            } else {
                if ($settingInfo["domain"]) {
                    $domain = $settingInfo["httpType"] . $settingInfo["domain"] . "/index.php?s=";
                }
            }
        }
        Set("domain",$domain);
        /*静态域名*/
        $domainStatic = str_replace('/index.php?s=', '', $domain);
        Set("domainStatic",$domainStatic);

        return $next($request);
    }
}
