<?php
// +----------------------------------------------------------------------
// | ThinkPHP [ WE CAN DO IT JUST THINK ]
// +----------------------------------------------------------------------
// | Copyright (c) 2006~2021 http://thinkphp.cn All rights reserved.
// +----------------------------------------------------------------------
// | Licensed ( http://www.apache.org/licenses/LICENSE-2.0 )
// +----------------------------------------------------------------------
// | Author: liu21st <liu21st@gmail.com>
// +----------------------------------------------------------------------
declare (strict_types = 1);

namespace app\middleware;

use app\admin\content\domain\service\DomainService;
use Closure;
use think\App;
use think\Cache;
use think\Config;
use think\facade\Db;
use think\Request;
use think\Response;


class CheckDomain
{

    protected $app;
    protected $config;

    public function __construct(App $app,  Config $config)
    {
        $this->app    = $app;
        $this->config    = $app;
    }
    /**
     * 验证域名
     * @access public
     * @param Request $request
     * @param Closure $next
     * @return Response
     */
    public function handle(Request $request, Closure $next)
    {
        $request->__set("siteInfo", []);
        if (is_file(ROOT_PATH . 'install' . DS .'install.lock')) {

            $host = $request->server()['HTTP_HOST'];
            $host_parts = explode('.', $host);
            $prefixHost = '';
            if (count($host_parts) > 2) {
                $prefixHost = array_shift($host_parts);
            }
            $suffixHost = implode('.', $host_parts);

            /*当前scheme*/
            $scheme = $request->scheme();
            Set("currentScheme",$scheme);
            /*当前域名前缀*/
            Set("currentPrefixHost",$prefixHost);
            /*当前顶级域名*/
//            Set("currentTopDomain",$suffixHost);
            Set("currentSuffixHost",$suffixHost);

            /*当前host*/
            Set("currentHost",$host);
            /*当前域名地址*/
            Set("currentDomain",$request->domain());

            Set("isCMS",true);
            $isCMS = true;

            /*获取数据库配置*/
            $databaseData = config("database");
            $dbName = $databaseData["connections"]["mysql"]["database"];
            $siteInfo = ["id" => 0,"pid" => 0,"web_url" => $request->domain(),"db_name" => $dbName];
            /*判断是否有siteId*/
            $siteId = $request->header("Site-Id");
            if (!$isCMS && $siteId) {
                /*查询当前站点的信息*/
                $siteInfo = Db::table("site")->where("id", $siteId)->find();
            } else {
//                if ($prefixHost == "") {
//                    Header("HTTP/1.1 302 Moved Permanently");
//                    Header("Location: " . $scheme . '://www.' . $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"]);
//                    exit;
//                }
                if (!$isCMS) {
                    $siteInfo = Db::table("site")->where('domain', $host)->find();
                    /*多域名处理*/
                    if ($siteInfo && intval($siteInfo["pid"]) != 0) {
                        $parentSiteInfo = Db::table('site')->where('id', $siteInfo["pid"])->find();
                        if ($parentSiteInfo) {
                            $siteInfo = $parentSiteInfo;
                        }
                    }
                }
            }
            if ($siteInfo) {
                $request->__set("siteInfo", $siteInfo);
                Set("siteInfo", $siteInfo);
            }

        }
        return $next($request);
    }

}
