<?php
// +----------------------------------------------------------------------
// | ThinkPHP [ WE CAN DO IT JUST THINK ]
// +----------------------------------------------------------------------
// | Copyright (c) 2006~2021 http://thinkphp.cn All rights reserved.
// +----------------------------------------------------------------------
// | Licensed ( http://www.apache.org/licenses/LICENSE-2.0 )
// +----------------------------------------------------------------------
// | Author: liu21st <liu21st@gmail.com>
// +----------------------------------------------------------------------
declare (strict_types = 1);

namespace app\middleware;

use app\admin\content\domain\service\DomainService;
use Closure;
use think\App;
use think\Cache;
use think\Config;
use think\facade\Db;
use think\Request;
use think\Response;


class Init
{

    protected $app;
    protected $config;

    public function __construct(App $app,  Config $config)
    {
        $this->app    = $app;
        $this->config    = $app;
    }
    /**
     * 验证域名
     * @access public
     * @param Request $request
     * @param Closure $next
     * @return Response
     */
    public function handle(Request $request, Closure $next)
    {
        if (is_file(ROOT_PATH . 'install' . DS .'install.lock')) {
            $this->tagDomainInit($request);
            $this->cityDomainInit($request);
            $this->levelTwoDomainInit($request);
        }
        return $next($request);
    }


    public function tagDomainInit(Request $request) {

        Set("isTagDomain",false);
        $request->__set("isTagDomain", false);

        $request->__set("tagDomainUrlName", "");

        $siteInfo = $request->__get("siteInfo");
        if ($siteInfo) {
            $addonsInfo = db("base_addons")->where("name","tagDomain")->find();
            if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
                /*验证当前是否开启tagDomain插件*/
                Set("isTagDomain",true);
                $request->__set("isTagDomain", true);
                /*根据当前访问域名 获取二级前缀*/
                $currentPrefixHost = Get("currentPrefixHost");
                if (db("tag")->where("url_name",$currentPrefixHost)->find()) {
                    $request->__set("tagDomainUrlName", $currentPrefixHost);
                }
            }
        }
    }

    public function cityDomainInit(Request $request) {

        Set("isCityDomain",false);
        Set('cityInfo',[]);
        $request->__set("isCityDomain", false);

        $request->__set("cityDomainUrlName", "");
        $currentSuffixHost = Get("currentSuffixHost");

        $siteInfo = $request->__get("siteInfo");

        if ($siteInfo) {
            $addonsInfo = db("base_addons")->where("name","city")->find();
            if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
                Set("isCityDomain",true);
                $request->__set("isCityDomain", true);
                /*根据当前访问域名 获取二级前缀*/
                $cityName = Get("currentPrefixHost");
                $cityInfo = db('addons_city')->where('pinyin',$cityName)->find();
                if ($cityInfo) {
                    $request->__set("cityDomainUrlName", $cityName);
                    Set('cityInfo',$cityInfo);
                }
            }
        } else {
            /*兼容非www站点情况*/
            try {
                $siteList = Db::table("site")->where("is_more_two_domain", 1)->select()->all();

                if ($siteList) {
                    $siteInfo = [];
                    foreach ($siteList as $key => $item) {
                        if (strpos($item["domain"],$currentSuffixHost) !== false) {
                            $siteInfo = $item;
                            break;
                        }
                    }
                    if ($siteInfo) {
                        Set("siteInfo",$siteInfo);
                        $request->__set("siteInfo", $siteInfo);
                        $addonsInfo = db("base_addons")->where("name","city")->find();
                        if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
                            Set("isCityDomain",true);
                            $request->__set("isCityDomain", true);
                            /*根据当前访问域名 获取二级前缀*/
                            $cityName = Get("currentPrefixHost");
                            $cityInfo = db('addons_city')->where('pinyin',$cityName)->find();
                            if ($cityInfo) {
                                $request->__set("cityDomainUrlName", $cityName);
                                Set('cityInfo',$cityInfo);
                            }
                        }
                    }
                }
            } catch (\Exception $e) {}
        }
    }


    public function levelTwoDomainInit(Request $request) {
        /*任意二级域名跳转到主站*/
        $currentPrefixHost = Get("currentPrefixHost");
        $siteInfo = Get("siteInfo");
        if ($currentPrefixHost != "www") {
            $currentSuffixHost = Get("currentSuffixHost");
            $fullMasterDomain = "www." . $currentSuffixHost;
            $isCMS = Get("isCMS");
            if (!$isCMS) {
                $siteInfo = Db::table("site")->where("domain", $fullMasterDomain)->find();
            }
            if ($siteInfo) {
                /*跳转插件*/
                $addonsInfo = db("base_addons")->where("name","twoLevelDomainJump")->find();
                if ($addonsInfo && $addonsInfo["is_disable"] == 0) {
                    $requestUrl = $request->server()['REQUEST_URI'];
                    Header("HTTP/1.1 302 Moved Permanently");
                    Header("Location: " . $fullMasterDomain . $requestUrl);
                    exit;
                }
            }
        }
    }
}
